<h1 align="center" style="margin: 30px 0 30px; font-weight: bold;">SiWeiCloud v3.6.5.1</h1>
<h4 align="center">基于 Vue/Element UI 和 Spring Boot/Spring Cloud & Alibaba 前后端分离的分布式微服务架构</h4>

## 平台简介

是一套全部开源的快速开发平台。

* 采用前后端分离的模式
* 微服务版本前端基于 Vue3。
* 后端采用Spring Boot、Spring Cloud & Alibaba。
* 注册中心、配置中心选型Nacos，权限认证使用Redis。
* 流量控制框架选型Sentinel，分布式事务选型Seata。
* 此服务提供[<font color=DarkTurquoise> 前端</font>  ] + [<font color=DarkTurquoise> 后端</font>] + [<font color=DarkTurquoise> nacos</font>] 服务
* nacos支持postgres数据库

## 系统模块

~~~
com.siwei     
├── siwei-web             // 前端框架 [80]
├── siwei-gateway         // 网关模块 [8080]
├── siwei-auth            // 认证中心 [9200]
├── siwei-api             // 接口模块
│       └── siwei-api-system                          // 系统接口
├── siwei-common          // 通用模块
│       └── siwei-common-core                         // 核心模块
│       └── siwei-common-datascope                    // 权限范围
│       └── siwei-common-datasource                   // 多数据源
│       └── siwei-common-log                          // 日志记录
│       └── siwei-common-redis                        // 缓存服务
│       └── siwei-common-seata                        // 分布式事务
│       └── siwei-common-security                     // 安全模块
│       └── siwei-common-sensitive                    // 数据脱敏
│       └── siwei-common-swagger                      // 系统接口
├── siwei-modules         // 业务模块
│       └── siwei-system                              // 系统模块 [9201]
│       └── siwei-gen                                 // 代码生成 [9202]
│       └── siwei-job                                 // 定时任务 [9203]
│       └── siwei-file                                // 文件服务 [9300]
│       └── siwei-spatial                             // 空间处理服务 [9204]
├── siwei-visual          // 图形化管理模块
│       └── siwei-visual-monitor                      // 监控中心 [9100]
├── siwei-nacos-2.3.2                                 // 注册中心naocs [7848、8848、9848]
├──pom.xml                // 公共依赖
~~~

## 架构图

![architectureDiagram.png](architectureDiagram.png)

## 内置功能

1.  用户管理：用户是系统操作者，该功能主要完成系统用户配置。
2.  部门管理：配置系统组织机构（公司、部门、小组），树结构展现支持数据权限。
3.  岗位管理：配置系统用户所属担任职务。
4.  菜单管理：配置系统菜单，操作权限，按钮权限标识等。
5.  角色管理：角色菜单权限分配、设置角色按机构进行数据范围权限划分。
6.  字典管理：对系统中经常使用的一些较为固定的数据进行维护。
7.  参数管理：对系统动态配置常用参数。
8.  通知公告：系统通知公告信息发布维护。
9.  操作日志：系统正常操作日志记录和查询；系统异常信息日志记录和查询。
10. 登录日志：系统登录日志记录查询包含登录异常。
11. 在线用户：当前系统中活跃用户状态监控。
12. 定时任务：在线（添加、修改、删除)任务调度包含执行结果日志。
13. 代码生成暂无：前后端代码的生成（java、html、xml、sql）支持CRUD下载 。
14. 系统接口：根据业务代码自动生成相关的api接口文档。
15. 服务监控：监视当前系统CPU、内存、磁盘、堆栈等相关信息。
16. 在线构建器：拖动表单元素生成相应的HTML代码。
17. 连接池监视：监视当前系统数据库连接池状态，可进行分析SQL找出系统性能瓶颈。

## 在线体验

- admin/admin123  
- 陆陆续续收到一些打赏，为了更好的体验已用于演示服务器升级。谢谢各位小伙伴。

## 底层

- 基于若依框架

## 子工程
### 子工程说明
> 通过分支版本添加对应的子模块方式进行项目场景的开发，
>> 比如说审核系统，在siwei-cloud项目中，创建审核系统的分支siwei-rsmonitoring

>> 创建.gitmodules执行代码前后代码模块所在位置，进行模块化开发
```bash 
[submodule "siwei-modules/siwei-rsmonitoring"]
	path = siwei-modules/siwei-rsmonitoring
	url = http://114.244.114.158:8802/siwei/siwei-rsmonitoring.git

[submodule "siwei-web"]
	path = siwei-web
	url = http://114.244.114.158:8802/siwei/rsmonitoring-manage.git
```



### 1.添加子工程
```bash 
  git submodule add http://114.244.114.158:8802/siwei/siwei-rsmonitoring.git siwei-modules/siwei-rsmonitoring
```
### 2.初始化并拉取子模块的代码
```bash
  git submodule update --init --recursive
```
### 3.更新子模块代码
进入子模块目录，进行相关的操作