package com.siwei.rsmonitoring.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.siwei.common.log.annotation.Log;
import com.siwei.common.log.enums.BusinessType;
import com.siwei.common.security.annotation.RequiresPermissions;
import com.siwei.rsmonitoring.domain.TDkAuditflowStep;
import com.siwei.rsmonitoring.service.ITDkAuditflowStepService;
import com.siwei.common.core.web.controller.BaseController;
import com.siwei.common.core.web.domain.AjaxResult;
import com.siwei.common.core.utils.poi.ExcelUtil;
import com.siwei.common.core.web.page.TableDataInfo;

/**
 * 地块的审核流程步骤Controller
 * 
 * @author siwei
 * @date 2025-01-20
 */
@RestController
@RequestMapping("/auditflow/step")
public class TDkAuditflowStepController extends BaseController
{
    @Autowired
    private ITDkAuditflowStepService tDkAuditflowStepService;

    /**
     * 查询地块的审核流程步骤列表
     */
    @RequiresPermissions("rsmonitoring:step:list")
    @GetMapping("/list")
    public TableDataInfo list(TDkAuditflowStep tDkAuditflowStep)
    {
        startPage();
        List<TDkAuditflowStep> list = tDkAuditflowStepService.selectTDkAuditflowStepList(tDkAuditflowStep);
        return getDataTable(list);
    }

    /**
     * 导出地块的审核流程步骤列表
     */
    @RequiresPermissions("rsmonitoring:step:export")
    @Log(title = "地块的审核流程步骤", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TDkAuditflowStep tDkAuditflowStep)
    {
        List<TDkAuditflowStep> list = tDkAuditflowStepService.selectTDkAuditflowStepList(tDkAuditflowStep);
        ExcelUtil<TDkAuditflowStep> util = new ExcelUtil<TDkAuditflowStep>(TDkAuditflowStep.class);
        util.exportExcel(response, list, "地块的审核流程步骤数据");
    }

    /**
     * 获取地块的审核流程步骤详细信息
     */
    @RequiresPermissions("rsmonitoring:step:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tDkAuditflowStepService.selectTDkAuditflowStepById(id));
    }

    /**
     * 新增地块的审核流程步骤
     */
    @RequiresPermissions("rsmonitoring:step:add")
    @Log(title = "地块的审核流程步骤", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TDkAuditflowStep tDkAuditflowStep)
    {
        return toAjax(tDkAuditflowStepService.insertTDkAuditflowStep(tDkAuditflowStep));
    }

    /**
     * 修改地块的审核流程步骤
     */
    @RequiresPermissions("rsmonitoring:step:edit")
    @Log(title = "地块的审核流程步骤", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TDkAuditflowStep tDkAuditflowStep)
    {
        return toAjax(tDkAuditflowStepService.updateTDkAuditflowStep(tDkAuditflowStep));
    }

    /**
     * 删除地块的审核流程步骤
     */
    @RequiresPermissions("rsmonitoring:step:remove")
    @Log(title = "地块的审核流程步骤", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tDkAuditflowStepService.deleteTDkAuditflowStepByIds(ids));
    }
}
