package com.siwei.rsmonitoring.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.siwei.common.log.annotation.Log;
import com.siwei.common.log.enums.BusinessType;
import com.siwei.common.security.annotation.RequiresPermissions;
import com.siwei.rsmonitoring.domain.TZdkjbxx;
import com.siwei.rsmonitoring.service.ITZdkjbxxService;
import com.siwei.common.core.web.controller.BaseController;
import com.siwei.common.core.web.domain.AjaxResult;
import com.siwei.common.core.utils.poi.ExcelUtil;
import com.siwei.common.core.web.page.TableDataInfo;

/**
 * 地块基本信息（DKJBXX）Controller
 * 
 * @author siwei
 * @date 2025-01-20
 */
@RestController
@RequestMapping("/zdkjbxx")
public class TZdkjbxxController extends BaseController
{
    @Autowired
    private ITZdkjbxxService tZdkjbxxService;

    /**
     * 查询地块基本信息（DKJBXX）列表
     */
    @RequiresPermissions("rsmonitoring:zdkjbxx:list")
    @GetMapping("/list")
    public TableDataInfo list(TZdkjbxx tZdkjbxx)
    {
        startPage();
        List<TZdkjbxx> list = tZdkjbxxService.selectTZdkjbxxList(tZdkjbxx);
        return getDataTable(list);
    }

    /**
     * 导出地块基本信息（DKJBXX）列表
     */
    @RequiresPermissions("rsmonitoring:zdkjbxx:export")
    @Log(title = "地块基本信息（DKJBXX）", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TZdkjbxx tZdkjbxx)
    {
        List<TZdkjbxx> list = tZdkjbxxService.selectTZdkjbxxList(tZdkjbxx);
        ExcelUtil<TZdkjbxx> util = new ExcelUtil<TZdkjbxx>(TZdkjbxx.class);
        util.exportExcel(response, list, "地块基本信息（DKJBXX）数据");
    }

    /**
     * 获取地块基本信息（DKJBXX）详细信息
     */
    @RequiresPermissions("rsmonitoring:zdkjbxx:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tZdkjbxxService.selectTZdkjbxxById(id));
    }

    /**
     * 新增地块基本信息（DKJBXX）
     */
    @RequiresPermissions("rsmonitoring:zdkjbxx:add")
    @Log(title = "地块基本信息（DKJBXX）", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TZdkjbxx tZdkjbxx)
    {
        return toAjax(tZdkjbxxService.insertTZdkjbxx(tZdkjbxx));
    }

    /**
     * 修改地块基本信息（DKJBXX）
     */
    @RequiresPermissions("rsmonitoring:zdkjbxx:edit")
    @Log(title = "地块基本信息（DKJBXX）", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TZdkjbxx tZdkjbxx)
    {
        return toAjax(tZdkjbxxService.updateTZdkjbxx(tZdkjbxx));
    }

    /**
     * 删除地块基本信息（DKJBXX）
     */
    @RequiresPermissions("rsmonitoring:zdkjbxx:remove")
    @Log(title = "地块基本信息（DKJBXX）", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tZdkjbxxService.deleteTZdkjbxxByIds(ids));
    }
}
