package com.siwei.spatial.service.file.impl;

import java.util.List;
import com.siwei.common.core.utils.DateUtils;
import com.siwei.spatial.api.domain.file.TGeomDb;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.siwei.spatial.mapper.file.TGeomDbMapper;
import com.siwei.spatial.service.file.ITGeomDbService;

/**
 * 空间入库存储Service业务层处理
 * 
 * @author siwei
 * @date 2025-02-05
 */
@Service
public class TGeomDbServiceImpl implements ITGeomDbService 
{
    @Autowired
    private TGeomDbMapper tGeomDbMapper;

    /**
     * 查询空间入库存储
     * 
     * @param id 空间入库存储主键
     * @return 空间入库存储
     */
    @Override
    public TGeomDb selectTGeomDbById(String id)
    {
        return tGeomDbMapper.selectTGeomDbById(id);
    }

    /**
     * 查询空间入库存储列表
     * 
     * @param tGeomDb 空间入库存储
     * @return 空间入库存储
     */
    @Override
    public List<TGeomDb> selectTGeomDbList(TGeomDb tGeomDb)
    {
        return tGeomDbMapper.selectTGeomDbList(tGeomDb);
    }

    /**
     * 新增空间入库存储
     * 
     * @param tGeomDb 空间入库存储
     * @return 结果
     */
    @Override
    public int insertTGeomDb(TGeomDb tGeomDb)
    {
        tGeomDb.setCreateTime(DateUtils.getNowDate());
        return tGeomDbMapper.insertTGeomDb(tGeomDb);
    }

    /**
     * 修改空间入库存储
     * 
     * @param tGeomDb 空间入库存储
     * @return 结果
     */
    @Override
    public int updateTGeomDb(TGeomDb tGeomDb)
    {
        return tGeomDbMapper.updateTGeomDb(tGeomDb);
    }

    /**
     * 批量删除空间入库存储
     * 
     * @param ids 需要删除的空间入库存储主键
     * @return 结果
     */
    @Override
    public int deleteTGeomDbByIds(String[] ids)
    {
        return tGeomDbMapper.deleteTGeomDbByIds(ids);
    }

    /**
     * 删除空间入库存储信息
     * 
     * @param id 空间入库存储主键
     * @return 结果
     */
    @Override
    public int deleteTGeomDbById(String id)
    {
        return tGeomDbMapper.deleteTGeomDbById(id);
    }
}
