-- gen_table definition

-- Drop table

-- DROP TABLE gen_table;

CREATE TABLE gen_table (
	table_id bigserial NOT NULL,
	table_name varchar(200) DEFAULT ''::character varying NULL,
	table_comment varchar(500) DEFAULT ''::character varying NULL,
	sub_table_name varchar(64) NULL,
	sub_table_fk_name varchar(64) NULL,
	class_name varchar(100) DEFAULT ''::character varying NULL,
	tpl_category varchar(200) DEFAULT 'crud'::character varying NULL,
	tpl_web_type varchar(30) DEFAULT ''::character varying NULL,
	package_name varchar(100) NULL,
	module_name varchar(30) NULL,
	business_name varchar(30) NULL,
	function_name varchar(50) NULL,
	function_author varchar(50) NULL,
	gen_type bpchar(1) DEFAULT '0'::bpchar NULL,
	gen_path varchar(200) DEFAULT '/'::character varying NULL,
	"options" varchar(1000) NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(500) NULL,
	CONSTRAINT idx_19727_primary PRIMARY KEY (table_id)
);


-- gen_table_column definition

-- Drop table

-- DROP TABLE gen_table_column;

CREATE TABLE gen_table_column (
	column_id bigserial NOT NULL,
	table_id int8 NULL,
	column_name varchar(200) NULL,
	column_comment varchar(500) NULL,
	column_type varchar(100) NULL,
	java_type varchar(500) NULL,
	java_field varchar(200) NULL,
	is_pk bpchar(1) NULL,
	is_increment bpchar(1) NULL,
	is_required bpchar(1) NULL,
	is_insert bpchar(1) NULL,
	is_edit bpchar(1) NULL,
	is_list bpchar(1) NULL,
	is_query bpchar(1) NULL,
	query_type varchar(200) DEFAULT 'EQ'::character varying NULL,
	html_type varchar(200) NULL,
	dict_type varchar(200) DEFAULT ''::character varying NULL,
	sort int8 NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	CONSTRAINT idx_19743_primary PRIMARY KEY (column_id)
);


-- sys_config definition

-- Drop table

-- DROP TABLE sys_config;

CREATE TABLE sys_config (
	config_id serial4 NOT NULL,
	config_name varchar(100) DEFAULT ''::character varying NULL,
	config_key varchar(100) DEFAULT ''::character varying NULL,
	config_value varchar(500) DEFAULT ''::character varying NULL,
	config_type bpchar(1) DEFAULT 'N'::bpchar NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(500) NULL,
	CONSTRAINT idx_19754_primary PRIMARY KEY (config_id)
);


-- sys_dept definition

-- Drop table

-- DROP TABLE sys_dept;

CREATE TABLE sys_dept (
	dept_id bigserial NOT NULL,
	parent_id int8 DEFAULT '0'::bigint NULL,
	ancestors varchar(50) DEFAULT ''::character varying NULL,
	dept_name varchar(30) DEFAULT ''::character varying NULL,
	order_num int4 DEFAULT 0 NULL,
	leader varchar(20) NULL,
	phone varchar(11) NULL,
	email varchar(50) NULL,
	status bpchar(1) DEFAULT '0'::bpchar NULL,
	del_flag bpchar(1) DEFAULT '0'::bpchar NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	CONSTRAINT idx_19767_primary PRIMARY KEY (dept_id)
);


-- sys_dict_data definition

-- Drop table

-- DROP TABLE sys_dict_data;

CREATE TABLE sys_dict_data (
	dict_code bigserial NOT NULL,
	dict_sort int4 DEFAULT 0 NULL,
	dict_label varchar(100) DEFAULT ''::character varying NULL,
	dict_value varchar(100) DEFAULT ''::character varying NULL,
	dict_type varchar(100) DEFAULT ''::character varying NULL,
	css_class varchar(100) NULL,
	list_class varchar(100) NULL,
	is_default bpchar(1) DEFAULT 'N'::bpchar NULL,
	status bpchar(1) DEFAULT '0'::bpchar NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(500) NULL,
	CONSTRAINT idx_19780_primary PRIMARY KEY (dict_code)
);


-- sys_dict_type definition

-- Drop table

-- DROP TABLE sys_dict_type;

CREATE TABLE sys_dict_type (
	dict_id bigserial NOT NULL,
	dict_name varchar(100) DEFAULT ''::character varying NULL,
	dict_type varchar(100) DEFAULT ''::character varying NULL,
	status bpchar(1) DEFAULT '0'::bpchar NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(500) NULL,
	CONSTRAINT idx_19795_primary PRIMARY KEY (dict_id)
);
CREATE UNIQUE INDEX idx_19795_dict_type ON sys_dict_type USING btree (dict_type);


-- sys_job definition

-- Drop table

-- DROP TABLE sys_job;

CREATE TABLE sys_job (
	job_id bigserial NOT NULL,
	job_name varchar(64) DEFAULT ''::character varying NOT NULL,
	job_group varchar(64) DEFAULT 'DEFAULT'::character varying NOT NULL,
	invoke_target varchar(500) NOT NULL,
	cron_expression varchar(255) DEFAULT ''::character varying NULL,
	misfire_policy varchar(20) DEFAULT '3'::character varying NULL,
	concurrent bpchar(1) DEFAULT '1'::bpchar NULL,
	status bpchar(1) DEFAULT '0'::bpchar NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(500) DEFAULT ''::character varying NULL,
	CONSTRAINT idx_19807_primary PRIMARY KEY (job_id, job_name, job_group)
);


-- sys_job_log definition

-- Drop table

-- DROP TABLE sys_job_log;

CREATE TABLE sys_job_log (
	job_log_id bigserial NOT NULL,
	job_name varchar(64) NOT NULL,
	job_group varchar(64) NOT NULL,
	invoke_target varchar(500) NOT NULL,
	job_message varchar(500) NULL,
	status bpchar(1) DEFAULT '0'::bpchar NULL,
	exception_info varchar(2000) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	CONSTRAINT idx_19823_primary PRIMARY KEY (job_log_id)
);


-- sys_logininfor definition

-- Drop table

-- DROP TABLE sys_logininfor;

CREATE TABLE sys_logininfor (
	info_id bigserial NOT NULL,
	user_name varchar(50) DEFAULT ''::character varying NULL,
	ipaddr varchar(128) DEFAULT ''::character varying NULL,
	status bpchar(1) DEFAULT '0'::bpchar NULL,
	msg varchar(255) DEFAULT ''::character varying NULL,
	access_time timestamptz NULL,
	CONSTRAINT idx_19832_primary PRIMARY KEY (info_id)
);
CREATE INDEX idx_19832_idx_sys_logininfor_lt ON sys_logininfor USING btree (access_time);
CREATE INDEX idx_19832_idx_sys_logininfor_s ON sys_logininfor USING btree (status);


-- sys_menu definition

-- Drop table

-- DROP TABLE sys_menu;

CREATE TABLE sys_menu (
	menu_id bigserial NOT NULL,
	menu_name varchar(50) NOT NULL,
	parent_id int8 DEFAULT '0'::bigint NULL,
	order_num int4 DEFAULT 0 NULL,
	"path" varchar(200) DEFAULT ''::character varying NULL,
	component varchar(255) NULL,
	query varchar(255) NULL,
	route_name varchar(50) DEFAULT ''::character varying NULL,
	is_frame bpchar(1) DEFAULT '1' NULL,
	is_cache bpchar(1) DEFAULT '0' NULL,
	menu_type bpchar(1) DEFAULT ''::bpchar NULL,
	visible bpchar(1) DEFAULT '0'::bpchar NULL,
	perms varchar(100) NULL,
	icon varchar(100) DEFAULT '#'::character varying NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(500) DEFAULT ''::character varying NULL,
	status bpchar(1) DEFAULT '0' NULL,
	CONSTRAINT idx_19841_primary PRIMARY KEY (menu_id)
);


-- sys_notice definition

-- Drop table

-- DROP TABLE sys_notice;

CREATE TABLE sys_notice (
	notice_id serial4 NOT NULL,
	notice_title varchar(50) NOT NULL,
	notice_type bpchar(1) NOT NULL,
	notice_content bytea NULL,
	status bpchar(1) DEFAULT '0'::bpchar NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(255) NULL,
	CONSTRAINT idx_19861_primary PRIMARY KEY (notice_id)
);


-- sys_oper_log definition

-- Drop table

-- DROP TABLE sys_oper_log;

CREATE TABLE sys_oper_log (
	oper_id bigserial NOT NULL,
	title varchar(50) DEFAULT ''::character varying NULL,
	business_type int4 DEFAULT 0 NULL,
	"method" varchar(200) DEFAULT ''::character varying NULL,
	request_method varchar(10) DEFAULT ''::character varying NULL,
	operator_type int4 DEFAULT 0 NULL,
	oper_name varchar(50) DEFAULT ''::character varying NULL,
	dept_name varchar(50) DEFAULT ''::character varying NULL,
	oper_url varchar(255) DEFAULT ''::character varying NULL,
	oper_ip varchar(128) DEFAULT ''::character varying NULL,
	oper_location varchar(255) DEFAULT ''::character varying NULL,
	oper_param varchar(2000) DEFAULT ''::character varying NULL,
	json_result varchar(2000) DEFAULT ''::character varying NULL,
	status int4 DEFAULT 0 NULL,
	error_msg varchar(2000) DEFAULT ''::character varying NULL,
	oper_time timestamptz NULL,
	cost_time int8 DEFAULT '0'::bigint NULL,
	CONSTRAINT idx_19871_primary PRIMARY KEY (oper_id)
);
CREATE INDEX idx_19871_idx_sys_oper_log_bt ON sys_oper_log USING btree (business_type);
CREATE INDEX idx_19871_idx_sys_oper_log_ot ON sys_oper_log USING btree (oper_time);
CREATE INDEX idx_19871_idx_sys_oper_log_s ON sys_oper_log USING btree (status);


-- sys_post definition

-- Drop table

-- DROP TABLE sys_post;

CREATE TABLE sys_post (
	post_id bigserial NOT NULL,
	post_code varchar(64) NOT NULL,
	post_name varchar(50) NOT NULL,
	post_sort int4 NOT NULL,
	status bpchar(1) NOT NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(500) NULL,
	CONSTRAINT idx_19893_primary PRIMARY KEY (post_id)
);


-- sys_role definition

-- Drop table

-- DROP TABLE sys_role;

CREATE TABLE sys_role (
	role_id bigserial NOT NULL,
	role_name varchar(30) NOT NULL,
	role_key varchar(100) NOT NULL,
	role_sort int4 NOT NULL,
	data_scope bpchar(1) DEFAULT '1'::bpchar NULL,
	menu_check_strictly bool DEFAULT true NULL,
	dept_check_strictly bool DEFAULT true NULL,
	status bpchar(1) NOT NULL,
	del_flag bpchar(1) DEFAULT '0'::bpchar NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(500) NULL,
	CONSTRAINT idx_19902_primary PRIMARY KEY (role_id)
);


-- sys_role_dept definition

-- Drop table

-- DROP TABLE sys_role_dept;

CREATE TABLE sys_role_dept (
	role_id int8 NOT NULL,
	dept_id int8 NOT NULL,
	CONSTRAINT idx_19914_primary PRIMARY KEY (role_id, dept_id)
);


-- sys_role_menu definition

-- Drop table

-- DROP TABLE sys_role_menu;

CREATE TABLE sys_role_menu (
	role_id int8 NOT NULL,
	menu_id int8 NOT NULL,
	CONSTRAINT idx_19917_primary PRIMARY KEY (role_id, menu_id)
);


-- sys_user definition

-- Drop table

-- DROP TABLE sys_user;

CREATE TABLE sys_user (
	user_id bigserial NOT NULL,
	dept_id int8 NULL,
	user_name varchar(30) NOT NULL,
	nick_name varchar(30) NOT NULL,
	user_type varchar(2) DEFAULT '00'::character varying NULL,
	email varchar(50) DEFAULT ''::character varying NULL,
	phonenumber varchar(11) DEFAULT ''::character varying NULL,
	sex bpchar(1) DEFAULT '0'::bpchar NULL,
	avatar varchar(100) DEFAULT ''::character varying NULL,
	"password" varchar(100) DEFAULT ''::character varying NULL,
	status bpchar(1) DEFAULT '0'::bpchar NULL,
	del_flag bpchar(1) DEFAULT '0'::bpchar NULL,
	login_ip varchar(128) DEFAULT ''::character varying NULL,
	login_date timestamptz NULL,
	create_by varchar(64) DEFAULT ''::character varying NULL,
	create_time timestamptz NULL,
	update_by varchar(64) DEFAULT ''::character varying NULL,
	update_time timestamptz NULL,
	remark varchar(500) NULL,
	CONSTRAINT idx_19921_primary PRIMARY KEY (user_id)
);


-- sys_user_post definition

-- Drop table

-- DROP TABLE sys_user_post;

CREATE TABLE sys_user_post (
	user_id int8 NOT NULL,
	post_id int8 NOT NULL,
	CONSTRAINT idx_19938_primary PRIMARY KEY (user_id, post_id)
);


-- sys_user_role definition

-- Drop table

-- DROP TABLE sys_user_role;

CREATE TABLE sys_user_role (
	user_id int8 NOT NULL,
	role_id int8 NOT NULL,
	CONSTRAINT idx_19941_primary PRIMARY KEY (user_id, role_id)
);


INSERT INTO "sys_config" ("config_id", "config_name", "config_key", "config_value", "config_type", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (1, '主框架页-默认皮肤样式名称', 'sys.index.skinName', 'skin-blue', 'Y', 'admin', '2025-01-07 15:47:32+00', '', NULL, '蓝色 skin-blue、绿色 skin-green、紫色 skin-purple、红色 skin-red、黄色 skin-yellow');
INSERT INTO "sys_config" ("config_id", "config_name", "config_key", "config_value", "config_type", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (2, '用户管理-账号初始密码', 'sys.user.initPassword', '123456', 'Y', 'admin', '2025-01-07 15:47:32+00', '', NULL, '初始化密码 123456');
INSERT INTO "sys_config" ("config_id", "config_name", "config_key", "config_value", "config_type", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (3, '主框架页-侧边栏主题', 'sys.index.sideTheme', 'theme-dark', 'Y', 'admin', '2025-01-07 15:47:32+00', '', NULL, '深色主题theme-dark，浅色主题theme-light');
INSERT INTO "sys_config" ("config_id", "config_name", "config_key", "config_value", "config_type", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (4, '账号自助-是否开启用户注册功能', 'sys.account.registerUser', 'false', 'Y', 'admin', '2025-01-07 15:47:32+00', '', NULL, '是否开启注册用户功能（true开启，false关闭）');
INSERT INTO "sys_config" ("config_id", "config_name", "config_key", "config_value", "config_type", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (5, '用户登录-黑名单列表', 'sys.login.blackIPList', '', 'Y', 'admin', '2025-01-07 15:47:32+00', '', NULL, '设置登录IP黑名单限制，多个匹配项以;分隔，支持匹配（*通配、网段）');
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (108, 102, '0,100,102', '市场部门', 1, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL);
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (109, 102, '0,100,102', '财务部门', 2, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL);
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (102, 100, '0,100', '北京分公司', 1, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', 'admin', '2025-01-09 07:47:25.856105+00');
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (103, 101, '0,100,101', '研发部门', 1, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL);
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (104, 101, '0,100,101', '市场部门', 2, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL);
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (105, 101, '0,100,101', '测试部门', 3, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL);
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (106, 101, '0,100,101', '财务部门', 4, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL);
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (107, 101, '0,100,101', '运维部门', 5, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL);
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (101, 100, '0,100', '深圳分公司', 2, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', 'admin', '2025-01-09 07:48:48.027814+00');
INSERT INTO "sys_dept" ("dept_id", "parent_id", "ancestors", "dept_name", "order_num", "leader", "phone", "email", "status", "del_flag", "create_by", "create_time", "update_by", "update_time") VALUES (100, 0, '0', '四维科技', 0, '四维', '15888888888', 'ry@qq.com', '0', '0', 'admin', '2025-01-07 15:47:32+00', 'admin', '2025-01-09 06:39:11.088832+00');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (1, 1, '男', '0', 'sys_user_sex', '', '', 'Y', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '性别男');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (2, 2, '女', '1', 'sys_user_sex', '', '', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '性别女');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (3, 3, '未知', '2', 'sys_user_sex', '', '', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '性别未知');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (4, 1, '显示', '0', 'sys_show_hide', '', 'primary', 'Y', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '显示菜单');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (5, 2, '隐藏', '1', 'sys_show_hide', '', 'danger', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '隐藏菜单');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (6, 1, '正常', '0', 'sys_normal_disable', '', 'primary', 'Y', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '正常状态');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (7, 2, '停用', '1', 'sys_normal_disable', '', 'danger', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '停用状态');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (8, 1, '正常', '0', 'sys_job_status', '', 'primary', 'Y', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '正常状态');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (9, 2, '暂停', '1', 'sys_job_status', '', 'danger', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '停用状态');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (10, 1, '默认', 'DEFAULT', 'sys_job_group', '', '', 'Y', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '默认分组');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (11, 2, '系统', 'SYSTEM', 'sys_job_group', '', '', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '系统分组');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (12, 1, '是', 'Y', 'sys_yes_no', '', 'primary', 'Y', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '系统默认是');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (13, 2, '否', 'N', 'sys_yes_no', '', 'danger', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '系统默认否');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (14, 1, '通知', '1', 'sys_notice_type', '', 'warning', 'Y', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '通知');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (15, 2, '公告', '2', 'sys_notice_type', '', 'success', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '公告');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (16, 1, '正常', '0', 'sys_notice_status', '', 'primary', 'Y', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '正常状态');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (17, 2, '关闭', '1', 'sys_notice_status', '', 'danger', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '关闭状态');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (18, 99, '其他', '0', 'sys_oper_type', '', 'info', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '其他操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (19, 1, '新增', '1', 'sys_oper_type', '', 'info', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '新增操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (20, 2, '修改', '2', 'sys_oper_type', '', 'info', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '修改操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (21, 3, '删除', '3', 'sys_oper_type', '', 'danger', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '删除操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (22, 4, '授权', '4', 'sys_oper_type', '', 'primary', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '授权操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (23, 5, '导出', '5', 'sys_oper_type', '', 'warning', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '导出操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (24, 6, '导入', '6', 'sys_oper_type', '', 'warning', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '导入操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (25, 7, '强退', '7', 'sys_oper_type', '', 'danger', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '强退操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (26, 8, '生成代码', '8', 'sys_oper_type', '', 'warning', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '生成操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (27, 9, '清空数据', '9', 'sys_oper_type', '', 'danger', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '清空操作');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (28, 1, '成功', '0', 'sys_common_status', '', 'primary', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '正常状态');
INSERT INTO "sys_dict_data" ("dict_code", "dict_sort", "dict_label", "dict_value", "dict_type", "css_class", "list_class", "is_default", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (29, 2, '失败', '1', 'sys_common_status', '', 'danger', 'N', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '停用状态');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (1, '用户性别', 'sys_user_sex', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '用户性别列表');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (2, '菜单状态', 'sys_show_hide', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '菜单状态列表');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (3, '系统开关', 'sys_normal_disable', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '系统开关列表');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (4, '任务状态', 'sys_job_status', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '任务状态列表');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (5, '任务分组', 'sys_job_group', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '任务分组列表');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (6, '系统是否', 'sys_yes_no', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '系统是否列表');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (7, '通知类型', 'sys_notice_type', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '通知类型列表');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (8, '通知状态', 'sys_notice_status', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '通知状态列表');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (9, '操作类型', 'sys_oper_type', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '操作类型列表');
INSERT INTO "sys_dict_type" ("dict_id", "dict_name", "dict_type", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (10, '系统状态', 'sys_common_status', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '登录状态列表');
INSERT INTO "sys_job" ("job_id", "job_name", "job_group", "invoke_target", "cron_expression", "misfire_policy", "concurrent", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (1, '系统默认（无参）', 'DEFAULT', 'ryTask.ryNoParams', '0/10 * * * * ?', '3', '1', '1', 'admin', '2025-01-07 15:47:32+00', '', NULL, '');
INSERT INTO "sys_job" ("job_id", "job_name", "job_group", "invoke_target", "cron_expression", "misfire_policy", "concurrent", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (2, '系统默认（有参）', 'DEFAULT', 'ryTask.ryParams(''ry'')', '0/15 * * * * ?', '3', '1', '1', 'admin', '2025-01-07 15:47:32+00', '', NULL, '');
INSERT INTO "sys_job" ("job_id", "job_name", "job_group", "invoke_target", "cron_expression", "misfire_policy", "concurrent", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (3, '系统默认（多参）', 'DEFAULT', 'ryTask.ryMultipleParams(''ry'', true, 2000L, 316.50D, 100)', '0/20 * * * * ?', '3', '1', '1', 'admin', '2025-01-07 15:47:32+00', '', NULL, '');
INSERT INTO "sys_job" ("job_id", "job_name", "job_group", "invoke_target", "cron_expression", "misfire_policy", "concurrent", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (4, '12', 'DEFAULT', 'ryTask.ryNoParams', '* * * * * ?', '3', '1', '1', 'admin', '2025-01-08 09:34:10.147241+00', '', NULL, '');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (100, 'admin', '192.168.60.66', '0', '登录成功', '2025-01-07 15:54:16+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (101, 'admin', '192.168.60.66', '0', '退出成功', '2025-01-07 15:55:49+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (102, 'admin', '192.168.60.66', '1', '密码输入错误1次', '2025-01-07 15:55:56+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (103, 'admin', '192.168.60.66', '1', '密码输入错误2次', '2025-01-07 15:56:06+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (104, 'admin', '192.168.60.66', '0', '登录成功', '2025-01-07 15:56:17+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (105, 'admin', '192.168.60.66', '0', '退出成功', '2025-01-07 15:56:21+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (106, 'admin', '192.168.60.66', '1', '密码输入错误1次', '2025-01-07 15:56:41+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (107, 'admin', '192.168.60.66', '0', '登录成功', '2025-01-07 15:57:12+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (108, 'admin', '192.168.60.66', '0', '退出成功', '2025-01-07 16:55:22+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (109, 'admin', '192.168.60.66', '0', '登录成功', '2025-01-07 16:55:27+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (110, 'admin', '127.0.0.1', '0', '登录成功', '2025-01-08 08:24:51.267386+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (111, 'admin', '127.0.0.1', '0', '退出成功', '2025-01-08 08:57:55.965712+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (112, 'admin', '127.0.0.1', '0', '登录成功', '2025-01-08 08:58:06.380017+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (113, 'admin', '192.168.60.66', '0', '登录成功', '2025-01-09 06:36:59.760646+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (114, 'admin', '127.0.0.1', '0', '退出成功', '2025-01-09 06:40:51.05272+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (115, 'admin', '127.0.0.1', '0', '登录成功', '2025-01-09 06:40:54.952724+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (116, 'admin', '127.0.0.1', '0', '退出成功', '2025-01-09 06:52:59.197856+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (117, 'admin', '127.0.0.1', '0', '登录成功', '2025-01-09 06:53:12.873003+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (118, 'admin', '127.0.0.1', '0', '退出成功', '2025-01-09 06:55:34.667573+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (119, 'admin', '127.0.0.1', '0', '登录成功', '2025-01-09 06:55:38.627797+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (120, 'admin', '127.0.0.1', '0', '退出成功', '2025-01-09 06:56:18.364808+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (121, 'admin', '127.0.0.1', '0', '登录成功', '2025-01-09 06:56:21.310151+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (122, 'admin', '127.0.0.1', '0', '退出成功', '2025-01-09 07:01:40.949254+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (123, 'admin', '127.0.0.1', '0', '登录成功', '2025-01-09 07:01:44.453024+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (124, 'admin', '127.0.0.1', '0', '登录成功', '2025-01-09 07:06:35.132386+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (125, 'admin', '192.168.60.66', '0', '退出成功', '2025-01-09 07:24:32.161647+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (126, 'admin', '192.168.60.66', '0', '登录成功', '2025-01-09 07:24:38.197269+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (127, 'admin', '192.168.60.66', '0', '退出成功', '2025-01-09 07:38:55.949573+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (128, 'admin', '192.168.60.66', '1', '密码输入错误1次', '2025-01-09 07:40:58.573605+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (129, 'admin', '192.168.60.66', '0', '登录成功', '2025-01-09 07:41:20.643093+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (130, 'admin', '192.168.60.66', '0', '退出成功', '2025-01-09 07:41:52.159027+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (131, 'ry', '192.168.60.66', '0', '登录成功', '2025-01-09 07:41:59.729675+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (132, 'ry', '192.168.60.66', '0', '退出成功', '2025-01-09 07:48:04.420059+00');
INSERT INTO "sys_logininfor" ("info_id", "user_name", "ipaddr", "status", "msg", "access_time") VALUES (133, 'admin', '192.168.60.66', '0', '登录成功', '2025-01-09 07:48:07.752357+00');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (500, '操作日志', 108, 1, 'operlog', 'system/operlog/index', '', '', '1', '0', 'C', '0', 'system:operlog:list', 'form', 'admin', '2025-01-07 15:47:32+00', '', NULL, '操作日志菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (501, '登录日志', 108, 2, 'logininfor', 'system/logininfor/index', '', '', '1', '0', 'C', '0', 'system:logininfor:list', 'logininfor', 'admin', '2025-01-07 15:47:32+00', '', NULL, '登录日志菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1000, '用户查询', 100, 1, '', '', '', '', '1', '0', 'F', '0', 'system:user:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1001, '用户新增', 100, 2, '', '', '', '', '1', '0', 'F', '0', 'system:user:add', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1002, '用户修改', 100, 3, '', '', '', '', '1', '0', 'F', '0', 'system:user:edit', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1003, '用户删除', 100, 4, '', '', '', '', '1', '0', 'F', '0', 'system:user:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1004, '用户导出', 100, 5, '', '', '', '', '1', '0', 'F', '0', 'system:user:export', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1005, '用户导入', 100, 6, '', '', '', '', '1', '0', 'F', '0', 'system:user:import', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1006, '重置密码', 100, 7, '', '', '', '', '1', '0', 'F', '0', 'system:user:resetPwd', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1007, '角色查询', 101, 1, '', '', '', '', '1', '0', 'F', '0', 'system:role:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1008, '角色新增', 101, 2, '', '', '', '', '1', '0', 'F', '0', 'system:role:add', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1009, '角色修改', 101, 3, '', '', '', '', '1', '0', 'F', '0', 'system:role:edit', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1010, '角色删除', 101, 4, '', '', '', '', '1', '0', 'F', '0', 'system:role:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1011, '角色导出', 101, 5, '', '', '', '', '1', '0', 'F', '0', 'system:role:export', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1012, '菜单查询', 102, 1, '', '', '', '', '1', '0', 'F', '0', 'system:menu:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1013, '菜单新增', 102, 2, '', '', '', '', '1', '0', 'F', '0', 'system:menu:add', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1014, '菜单修改', 102, 3, '', '', '', '', '1', '0', 'F', '0', 'system:menu:edit', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1015, '菜单删除', 102, 4, '', '', '', '', '1', '0', 'F', '0', 'system:menu:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1016, '部门查询', 103, 1, '', '', '', '', '1', '0', 'F', '0', 'system:dept:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1017, '部门新增', 103, 2, '', '', '', '', '1', '0', 'F', '0', 'system:dept:add', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1018, '部门修改', 103, 3, '', '', '', '', '1', '0', 'F', '0', 'system:dept:edit', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1019, '部门删除', 103, 4, '', '', '', '', '1', '0', 'F', '0', 'system:dept:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1020, '岗位查询', 104, 1, '', '', '', '', '1', '0', 'F', '0', 'system:post:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1021, '岗位新增', 104, 2, '', '', '', '', '1', '0', 'F', '0', 'system:post:add', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1022, '岗位修改', 104, 3, '', '', '', '', '1', '0', 'F', '0', 'system:post:edit', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1023, '岗位删除', 104, 4, '', '', '', '', '1', '0', 'F', '0', 'system:post:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1024, '岗位导出', 104, 5, '', '', '', '', '1', '0', 'F', '0', 'system:post:export', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1025, '字典查询', 105, 1, '#', '', '', '', '1', '0', 'F', '0', 'system:dict:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1026, '字典新增', 105, 2, '#', '', '', '', '1', '0', 'F', '0', 'system:dict:add', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1027, '字典修改', 105, 3, '#', '', '', '', '1', '0', 'F', '0', 'system:dict:edit', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1028, '字典删除', 105, 4, '#', '', '', '', '1', '0', 'F', '0', 'system:dict:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1029, '字典导出', 105, 5, '#', '', '', '', '1', '0', 'F', '0', 'system:dict:export', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1031, '参数新增', 106, 2, '#', '', '', '', '1', '0', 'F', '0', 'system:config:add', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1032, '参数修改', 106, 3, '#', '', '', '', '1', '0', 'F', '0', 'system:config:edit', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1033, '参数删除', 106, 4, '#', '', '', '', '1', '0', 'F', '0', 'system:config:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1034, '参数导出', 106, 5, '#', '', '', '', '1', '0', 'F', '0', 'system:config:export', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1035, '公告查询', 107, 1, '#', '', '', '', '1', '0', 'F', '0', 'system:notice:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1036, '公告新增', 107, 2, '#', '', '', '', '1', '0', 'F', '0', 'system:notice:add', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1037, '公告修改', 107, 3, '#', '', '', '', '1', '0', 'F', '0', 'system:notice:edit', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1038, '公告删除', 107, 4, '#', '', '', '', '1', '0', 'F', '0', 'system:notice:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1039, '操作查询', 500, 1, '#', '', '', '', '1', '0', 'F', '0', 'system:operlog:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1040, '操作删除', 500, 2, '#', '', '', '', '1', '0', 'F', '0', 'system:operlog:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1041, '日志导出', 500, 3, '#', '', '', '', '1', '0', 'F', '0', 'system:operlog:export', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1042, '登录查询', 501, 1, '#', '', '', '', '1', '0', 'F', '0', 'system:logininfor:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1043, '登录删除', 501, 2, '#', '', '', '', '1', '0', 'F', '0', 'system:logininfor:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1044, '日志导出', 501, 3, '#', '', '', '', '1', '0', 'F', '0', 'system:logininfor:export', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1045, '账户解锁', 501, 4, '#', '', '', '', '1', '0', 'F', '0', 'system:logininfor:unlock', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1046, '在线查询', 109, 1, '#', '', '', '', '1', '0', 'F', '0', 'monitor:online:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1047, '批量强退', 109, 2, '#', '', '', '', '1', '0', 'F', '0', 'monitor:online:batchLogout', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1048, '单条强退', 109, 3, '#', '', '', '', '1', '0', 'F', '0', 'monitor:online:forceLogout', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1049, '任务查询', 110, 1, '#', '', '', '', '1', '0', 'F', '0', 'monitor:job:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1050, '任务新增', 110, 2, '#', '', '', '', '1', '0', 'F', '0', 'monitor:job:add', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1051, '任务修改', 110, 3, '#', '', '', '', '1', '0', 'F', '0', 'monitor:job:edit', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1052, '任务删除', 110, 4, '#', '', '', '', '1', '0', 'F', '0', 'monitor:job:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1053, '状态修改', 110, 5, '#', '', '', '', '1', '0', 'F', '0', 'monitor:job:changeStatus', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1054, '任务导出', 110, 6, '#', '', '', '', '1', '0', 'F', '0', 'monitor:job:export', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1, '系统管理', 0, 1, 'system', NULL, '', '', '1', '0', 'M', '0', '', 'system', 'admin', '2025-01-07 15:47:32+00', '', NULL, '系统管理目录', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (2, '系统监控', 0, 2, 'monitor', NULL, '', '', '1', '0', 'M', '0', '', 'monitor', 'admin', '2025-01-07 15:47:32+00', '', NULL, '系统监控目录', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (3, '系统工具', 0, 3, 'tool', NULL, '', '', '1', '0', 'M', '0', '', 'tool', 'admin', '2025-01-07 15:47:32+00', '', NULL, '系统工具目录', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (100, '用户管理', 1, 1, 'user', 'system/user/index', '', '', '1', '0', 'C', '0', 'system:user:list', 'user', 'admin', '2025-01-07 15:47:32+00', '', NULL, '用户管理菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (101, '角色管理', 1, 2, 'role', 'system/role/index', '', '', '1', '0', 'C', '0', 'system:role:list', 'peoples', 'admin', '2025-01-07 15:47:32+00', '', NULL, '角色管理菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (102, '菜单管理', 1, 3, 'menu', 'system/menu/index', '', '', '1', '0', 'C', '0', 'system:menu:list', 'tree-table', 'admin', '2025-01-07 15:47:32+00', '', NULL, '菜单管理菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (103, '部门管理', 1, 4, 'dept', 'system/dept/index', '', '', '1', '0', 'C', '0', 'system:dept:list', 'tree', 'admin', '2025-01-07 15:47:32+00', '', NULL, '部门管理菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (104, '岗位管理', 1, 5, 'post', 'system/post/index', '', '', '1', '0', 'C', '0', 'system:post:list', 'post', 'admin', '2025-01-07 15:47:32+00', '', NULL, '岗位管理菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (105, '字典管理', 1, 6, 'dict', 'system/dict/index', '', '', '1', '0', 'C', '0', 'system:dict:list', 'dict', 'admin', '2025-01-07 15:47:32+00', '', NULL, '字典管理菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (106, '参数设置', 1, 7, 'config', 'system/config/index', '', '', '1', '0', 'C', '0', 'system:config:list', 'edit', 'admin', '2025-01-07 15:47:32+00', '', NULL, '参数设置菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (107, '通知公告', 1, 8, 'notice', 'system/notice/index', '', '', '1', '0', 'C', '0', 'system:notice:list', 'message', 'admin', '2025-01-07 15:47:32+00', '', NULL, '通知公告菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (108, '日志管理', 1, 9, 'log', '', '', '', '1', '0', 'M', '0', '', 'log', 'admin', '2025-01-07 15:47:32+00', '', NULL, '日志管理菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (109, '在线用户', 2, 1, 'online', 'monitor/online/index', '', '', '1', '0', 'C', '0', 'monitor:online:list', 'online', 'admin', '2025-01-07 15:47:32+00', '', NULL, '在线用户菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (110, '定时任务', 2, 2, 'job', 'monitor/job/index', '', '', '1', '0', 'C', '0', 'monitor:job:list', 'job', 'admin', '2025-01-07 15:47:32+00', '', NULL, '定时任务菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (112, 'Nacos控制台', 2, 4, 'http://localhost:8848/nacos', '', '', '', '0', '0', 'C', '0', 'monitor:nacos:list', 'nacos', 'admin', '2025-01-07 15:47:32+00', '', NULL, '服务治理菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (113, 'Admin控制台', 2, 5, 'http://localhost:9100/login', '', '', '', '0', '0', 'C', '0', 'monitor:server:list', 'server', 'admin', '2025-01-07 15:47:32+00', '', NULL, '服务监控菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (114, '表单构建', 3, 1, 'build', 'tool/build/index', '', '', '1', '0', 'C', '0', 'tool:build:list', 'build', 'admin', '2025-01-07 15:47:32+00', '', NULL, '表单构建菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (116, '系统接口', 3, 3, 'http://localhost:8080/swagger-ui/index.html', '', '', '', '0', '0', 'C', '0', 'tool:swagger:list', 'swagger', 'admin', '2025-01-07 15:47:32+00', '', NULL, '系统接口菜单', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1030, '参数查询', 106, 1, '#', '', '', '', '1', '0', 'F', '0', 'system:config:query', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1057, '生成删除', 115, 3, '#', '', '', '', '1', '0', 'F', '0', 'tool:gen:remove', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1059, '预览代码', 115, 4, '#', '', '', '', '1', '0', 'F', '0', 'tool:gen:preview', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1060, '生成代码', 115, 5, '#', '', '', '', '1', '0', 'F', '0', 'tool:gen:code', '#', 'admin', '2025-01-07 15:47:32+00', '', NULL, '', '0');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1055, '生成查询', 115, 1, '#', '', '', '', '1', '0', 'F', '0', 'tool:gen:query', '#', 'admin', '2025-01-07 15:47:32+00', 'admin', '2025-01-09 06:56:50.570473+00', '', '1');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1058, '导入代码', 115, 2, '#', '', '', '', '1', '0', 'F', '0', 'tool:gen:import', '#', 'admin', '2025-01-07 15:47:32+00', 'admin', '2025-01-09 06:56:54.320678+00', '', '1');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (1056, '生成修改', 115, 2, '#', '', '', '', '1', '0', 'F', '0', 'tool:gen:edit', '#', 'admin', '2025-01-07 15:47:32+00', 'admin', '2025-01-09 06:57:03.569763+00', '', '1');
INSERT INTO "sys_menu" ("menu_id", "menu_name", "parent_id", "order_num", "path", "component", "query", "route_name", "is_frame", "is_cache", "menu_type", "visible", "perms", "icon", "create_by", "create_time", "update_by", "update_time", "remark", "status") VALUES (115, '代码生成', 3, 2, 'gen', 'tool/gen/index', '', '', '1', '0', 'C', '0', 'tool:gen:list', 'code', 'admin', '2025-01-07 15:47:32+00', 'admin', '2025-01-09 07:25:06.997306+00', '代码生成菜单', '1');
INSERT INTO "sys_oper_log" ("oper_id", "title", "business_type", "method", "request_method", "operator_type", "oper_name", "dept_name", "oper_url", "oper_ip", "oper_location", "oper_param", "json_result", "status", "error_msg", "oper_time", "cost_time") VALUES (2, '用户管理', 1, 'com.ruoyi.system.controller.SysUserController.add()', 'POST', 1, 'admin', NULL, '/user', '127.0.0.1', '', '{"admin":false,"createBy":"admin","deptId":100,"nickName":"1","params":{},"phonenumber":"18000000000","postIds":[1],"remark":"1","roleIds":[],"sex":"0","status":"0","userId":3,"userName":"123456"}', '{"msg":"操作成功","code":200}', 0, NULL, '2025-01-08 08:47:35.749935+00', 150);
INSERT INTO "sys_oper_log" ("oper_id", "title", "business_type", "method", "request_method", "operator_type", "oper_name", "dept_name", "oper_url", "oper_ip", "oper_location", "oper_param", "json_result", "status", "error_msg", "oper_time", "cost_time") VALUES (43, '部门管理', 2, 'com.siwei.system.controller.SysDeptController.edit()', 'PUT', 1, 'admin', NULL, '/dept', '127.0.0.1', '', '{"ancestors":"0,100","children":[],"createBy":"admin","createTime":"2025-01-07 23:47:32","delFlag":"0","deptId":102,"deptName":"北京分公司","email":"ry@qq.com","leader":"若依","orderNum":2,"params":{},"parentId":100,"phone":"15888888888","status":"0","updateBy":"admin"}', '{"msg":"操作成功","code":200}', 0, NULL, '2025-01-09 07:46:51.344285+00', 27);
INSERT INTO "sys_oper_log" ("oper_id", "title", "business_type", "method", "request_method", "operator_type", "oper_name", "dept_name", "oper_url", "oper_ip", "oper_location", "oper_param", "json_result", "status", "error_msg", "oper_time", "cost_time") VALUES (46, '部门管理', 2, 'com.siwei.system.controller.SysDeptController.edit()', 'PUT', 1, 'admin', NULL, '/dept', '192.168.60.66', '', '{"ancestors":"0,100","children":[],"createBy":"admin","createTime":"2025-01-07 23:47:32","delFlag":"0","deptId":101,"deptName":"深圳分公司","email":"ry@qq.com","leader":"若依","orderNum":2,"params":{},"parentId":100,"phone":"15888888888","status":"0","updateBy":"admin"}', '{"msg":"操作成功","code":200}', 0, NULL, '2025-01-09 07:48:48.04059+00', 15);
INSERT INTO "sys_oper_log" ("oper_id", "title", "business_type", "method", "request_method", "operator_type", "oper_name", "dept_name", "oper_url", "oper_ip", "oper_location", "oper_param", "json_result", "status", "error_msg", "oper_time", "cost_time") VALUES (47, '岗位管理', 1, 'com.siwei.system.controller.SysPostController.add()', 'POST', 1, 'admin', NULL, '/post', '192.168.60.66', '', '{"createBy":"admin","flag":false,"params":{},"postCode":"111","postId":5,"postName":"111","postSort":11,"status":"0"}', '{"msg":"操作成功","code":200}', 0, NULL, '2025-01-09 07:49:11.822454+00', 13);
INSERT INTO "sys_oper_log" ("oper_id", "title", "business_type", "method", "request_method", "operator_type", "oper_name", "dept_name", "oper_url", "oper_ip", "oper_location", "oper_param", "json_result", "status", "error_msg", "oper_time", "cost_time") VALUES (48, '岗位管理', 3, 'com.siwei.system.controller.SysPostController.remove()', 'DELETE', 1, 'admin', NULL, '/post/5', '192.168.60.66', '', '[5]', '{"msg":"操作成功","code":200}', 0, NULL, '2025-01-09 07:49:15.595313+00', 7);
INSERT INTO "sys_post" ("post_id", "post_code", "post_name", "post_sort", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (1, 'ceo', '董事长', 1, '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '');
INSERT INTO "sys_post" ("post_id", "post_code", "post_name", "post_sort", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (2, 'se', '项目经理', 2, '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '');
INSERT INTO "sys_post" ("post_id", "post_code", "post_name", "post_sort", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (3, 'hr', '人力资源', 3, '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '');
INSERT INTO "sys_post" ("post_id", "post_code", "post_name", "post_sort", "status", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (4, 'user', '普通员工', 4, '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '');
INSERT INTO "sys_role" ("role_id", "role_name", "role_key", "role_sort", "data_scope", "menu_check_strictly", "dept_check_strictly", "status", "del_flag", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (1, '超级管理员', 'admin', 1, '1', 't', 't', '0', '0', 'admin', '2025-01-07 15:47:32+00', '', NULL, '超级管理员');
INSERT INTO "sys_role" ("role_id", "role_name", "role_key", "role_sort", "data_scope", "menu_check_strictly", "dept_check_strictly", "status", "del_flag", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (2, '普通角色', 'common', 2, '2', 't', 't', '0', '0', 'admin', '2025-01-07 15:47:32+00', 'admin', '2025-01-09 06:42:22.880055+00', '普通角色');
INSERT INTO "sys_role_dept" ("role_id", "dept_id") VALUES (2, 100);
INSERT INTO "sys_role_dept" ("role_id", "dept_id") VALUES (2, 101);
INSERT INTO "sys_role_dept" ("role_id", "dept_id") VALUES (2, 105);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 3);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 100);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1000);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1001);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1002);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1003);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1004);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1005);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1006);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 101);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1007);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1008);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1009);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1010);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1011);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 102);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1012);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1013);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1014);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1015);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 103);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1016);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1017);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1018);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1019);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 104);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1020);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1021);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1022);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1023);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1024);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 105);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1025);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1026);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1027);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1028);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1029);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 106);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1030);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1031);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1032);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1033);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1034);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 107);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1035);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1036);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1037);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1038);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 108);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 500);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1039);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1040);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1041);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 501);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1042);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1043);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1044);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1045);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 2);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 109);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1046);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1047);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1048);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 110);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1049);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1050);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1051);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1052);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1053);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 1054);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 112);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 113);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 114);
INSERT INTO "sys_role_menu" ("role_id", "menu_id") VALUES (2, 116);
INSERT INTO "sys_user" ("user_id", "dept_id", "user_name", "nick_name", "user_type", "email", "phonenumber", "sex", "avatar", "password", "status", "del_flag", "login_ip", "login_date", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (3, 100, '123456', '1', '00', '', '18000000000', '0', '', '$2a$10$6ge1pgN2r1rNTJ/FZD2s7egRLxOiaI1DtOu2krR27l2z6x15TokEu', '0', '0', '', NULL, 'admin', '2025-01-08 08:47:35.356943+00', '', NULL, '1');
INSERT INTO "sys_user" ("user_id", "dept_id", "user_name", "nick_name", "user_type", "email", "phonenumber", "sex", "avatar", "password", "status", "del_flag", "login_ip", "login_date", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (2, 105, 'ry', 'ceshi', '00', 'ry@qq.com', '15666666666', '1', '', '$2a$10$7JB720yubVSZvUI0rEqK/.VqGOZTH.ulu33dHOiBE8ByOhJIrdAu2', '0', '0', '192.168.60.66', '2025-01-09 07:41:59.657+00', 'admin', '2025-01-07 15:47:32+00', 'ry', '2025-01-09 07:43:54.359125+00', '测试员');
INSERT INTO "sys_user" ("user_id", "dept_id", "user_name", "nick_name", "user_type", "email", "phonenumber", "sex", "avatar", "password", "status", "del_flag", "login_ip", "login_date", "create_by", "create_time", "update_by", "update_time", "remark") VALUES (1, 103, 'admin', '若依', '00', 'ry@163.com', '15888888888', '1', '', '$2a$10$7JB720yubVSZvUI0rEqK/.VqGOZTH.ulu33dHOiBE8ByOhJIrdAu2', '0', '0', '192.168.60.66', '2025-01-09 07:48:07.676+00', 'admin', '2025-01-07 15:47:32+00', '', '2025-01-09 07:48:07.759656+00', '管理员');
INSERT INTO "sys_user_post" ("user_id", "post_id") VALUES (1, 1);
INSERT INTO "sys_user_post" ("user_id", "post_id") VALUES (3, 1);
INSERT INTO "sys_user_post" ("user_id", "post_id") VALUES (2, 2);
INSERT INTO "sys_user_role" ("user_id", "role_id") VALUES (1, 1);
INSERT INTO "sys_user_role" ("user_id", "role_id") VALUES (2, 2);


CREATE OR REPLACE FUNCTION "find_in_set"("search_value" int8, "string_list" text)
  RETURNS "pg_catalog"."bool" AS $BODY$
DECLARE
pos integer;
BEGIN
    pos := array_position(string_to_array(string_list, ','), search_value::TEXT);
RETURN pos > 0;
END;
$BODY$ LANGUAGE plpgsql VOLATILE COST 100 ;