-- config_info definition

-- Drop table

-- DROP TABLE config_info;

CREATE TABLE config_info (
                                      id bigserial NOT NULL,
                                      data_id varchar(255) NOT NULL,
                                      group_id varchar(128) NULL,
                                      "content" text NOT NULL,
                                      md5 varchar(32) NULL,
                                      gmt_create timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                      gmt_modified timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                      src_user text NULL,
                                      src_ip varchar(50) NULL,
                                      app_name varchar(128) NULL,
                                      tenant_id varchar(128) DEFAULT ''::character varying NULL,
                                      c_desc varchar(256) NULL,
                                      c_use varchar(64) NULL,
                                      effect varchar(64) NULL,
                                      "type" varchar(64) NULL,
                                      c_schema text NULL,
                                      encrypted_data_key text NOT NULL,
                                      CONSTRAINT idx_20447_primary PRIMARY KEY (id)
);
CREATE UNIQUE INDEX idx_20447_uk_configinfo_datagrouptenant ON config_info USING btree (data_id, group_id, tenant_id);


-- config_info_aggr definition

-- Drop table

-- DROP TABLE config_info_aggr;

CREATE TABLE config_info_aggr (
                                           id bigserial NOT NULL,
                                           data_id varchar(255) NOT NULL,
                                           group_id varchar(128) NOT NULL,
                                           datum_id varchar(255) NOT NULL,
                                           "content" text NOT NULL,
                                           gmt_modified timestamptz NOT NULL,
                                           app_name varchar(128) NULL,
                                           tenant_id varchar(128) DEFAULT ''::character varying NULL,
                                           CONSTRAINT idx_20457_primary PRIMARY KEY (id)
);
CREATE UNIQUE INDEX idx_20457_uk_configinfoaggr_datagrouptenantdatum ON config_info_aggr USING btree (data_id, group_id, tenant_id, datum_id);


-- config_info_beta definition

-- Drop table

-- DROP TABLE config_info_beta;

CREATE TABLE config_info_beta (
                                           id bigserial NOT NULL,
                                           data_id varchar(255) NOT NULL,
                                           group_id varchar(128) NOT NULL,
                                           app_name varchar(128) NULL,
                                           "content" text NOT NULL,
                                           beta_ips varchar(1024) NULL,
                                           md5 varchar(32) NULL,
                                           gmt_create timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                           gmt_modified timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                           src_user text NULL,
                                           src_ip varchar(50) NULL,
                                           tenant_id varchar(128) DEFAULT ''::character varying NULL,
                                           encrypted_data_key text NOT NULL,
                                           CONSTRAINT idx_20465_primary PRIMARY KEY (id)
);
CREATE UNIQUE INDEX idx_20465_uk_configinfobeta_datagrouptenant ON config_info_beta USING btree (data_id, group_id, tenant_id);


-- config_info_tag definition

-- Drop table

-- DROP TABLE config_info_tag;

CREATE TABLE config_info_tag (
                                          id bigserial NOT NULL,
                                          data_id varchar(255) NOT NULL,
                                          group_id varchar(128) NOT NULL,
                                          tenant_id varchar(128) DEFAULT ''::character varying NULL,
                                          tag_id varchar(128) NOT NULL,
                                          app_name varchar(128) NULL,
                                          "content" text NOT NULL,
                                          md5 varchar(32) NULL,
                                          gmt_create timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                          gmt_modified timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                          src_user text NULL,
                                          src_ip varchar(50) NULL,
                                          CONSTRAINT idx_20475_primary PRIMARY KEY (id)
);
CREATE UNIQUE INDEX idx_20475_uk_configinfotag_datagrouptenanttag ON config_info_tag USING btree (data_id, group_id, tenant_id, tag_id);


-- config_tags_relation definition

-- Drop table

-- DROP TABLE config_tags_relation;

CREATE TABLE config_tags_relation (
                                               id int8 NOT NULL,
                                               tag_name varchar(128) NOT NULL,
                                               tag_type varchar(64) NULL,
                                               data_id varchar(255) NOT NULL,
                                               group_id varchar(128) NOT NULL,
                                               tenant_id varchar(128) DEFAULT ''::character varying NULL,
                                               nid bigserial NOT NULL,
                                               CONSTRAINT idx_20485_primary PRIMARY KEY (nid)
);
CREATE INDEX idx_20485_idx_tenant_id ON config_tags_relation USING btree (tenant_id);
CREATE UNIQUE INDEX idx_20485_uk_configtagrelation_configidtag ON config_tags_relation USING btree (id, tag_name, tag_type);


-- group_capacity definition

-- Drop table

-- DROP TABLE group_capacity;

CREATE TABLE group_capacity (
                                         id bigserial NOT NULL,
                                         group_id varchar(128) DEFAULT ''::character varying NOT NULL,
                                         quota int8 DEFAULT '0'::bigint NOT NULL,
                                         "usage" int8 DEFAULT '0'::bigint NOT NULL,
                                         max_size int8 DEFAULT '0'::bigint NOT NULL,
                                         max_aggr_count int8 DEFAULT '0'::bigint NOT NULL,
                                         max_aggr_size int8 DEFAULT '0'::bigint NOT NULL,
                                         max_history_count int8 DEFAULT '0'::bigint NOT NULL,
                                         gmt_create timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                         gmt_modified timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                         CONSTRAINT idx_20493_primary PRIMARY KEY (id)
);
CREATE UNIQUE INDEX idx_20493_uk_group_id ON group_capacity USING btree (group_id);


-- his_config_info definition

-- Drop table

-- DROP TABLE his_config_info;

CREATE TABLE his_config_info (
                                          id numeric NOT NULL,
                                          nid bigserial NOT NULL,
                                          data_id varchar(255) NOT NULL,
                                          group_id varchar(128) NOT NULL,
                                          app_name varchar(128) NULL,
                                          "content" text NOT NULL,
                                          md5 varchar(32) NULL,
                                          gmt_create timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                          gmt_modified timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                          src_user text NULL,
                                          src_ip varchar(50) NULL,
                                          op_type bpchar(10) NULL,
                                          tenant_id varchar(128) DEFAULT ''::character varying NULL,
                                          encrypted_data_key text NOT NULL,
                                          CONSTRAINT idx_20507_primary PRIMARY KEY (nid)
);
CREATE INDEX idx_20507_idx_did ON his_config_info USING btree (data_id);
CREATE INDEX idx_20507_idx_gmt_create ON his_config_info USING btree (gmt_create);
CREATE INDEX idx_20507_idx_gmt_modified ON his_config_info USING btree (gmt_modified);


-- permissions definition

-- Drop table

-- DROP TABLE permissions;

CREATE TABLE permissions (
                                      "role" varchar(50) NOT NULL,
                                      resource varchar(128) NOT NULL,
                                      "action" varchar(8) NOT NULL
);
CREATE UNIQUE INDEX idx_20516_uk_role_permission ON permissions USING btree (role, resource, action);


-- roles definition

-- Drop table

-- DROP TABLE roles;

CREATE TABLE roles (
                                username varchar(50) NOT NULL,
                                "role" varchar(50) NOT NULL
);
CREATE UNIQUE INDEX idx_20519_idx_user_role ON roles USING btree (username, role);


-- tenant_capacity definition

-- Drop table

-- DROP TABLE tenant_capacity;

CREATE TABLE tenant_capacity (
                                          id bigserial NOT NULL,
                                          tenant_id varchar(128) DEFAULT ''::character varying NOT NULL,
                                          quota int8 DEFAULT '0'::bigint NOT NULL,
                                          "usage" int8 DEFAULT '0'::bigint NOT NULL,
                                          max_size int8 DEFAULT '0'::bigint NOT NULL,
                                          max_aggr_count int8 DEFAULT '0'::bigint NOT NULL,
                                          max_aggr_size int8 DEFAULT '0'::bigint NOT NULL,
                                          max_history_count int8 DEFAULT '0'::bigint NOT NULL,
                                          gmt_create timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                          gmt_modified timestamptz DEFAULT CURRENT_TIMESTAMP NOT NULL,
                                          CONSTRAINT idx_20523_primary PRIMARY KEY (id)
);
CREATE UNIQUE INDEX idx_20523_uk_tenant_id ON tenant_capacity USING btree (tenant_id);


-- tenant_info definition

-- Drop table

-- DROP TABLE tenant_info;

CREATE TABLE tenant_info (
                                      id bigserial NOT NULL,
                                      kp varchar(128) NOT NULL,
                                      tenant_id varchar(128) DEFAULT ''::character varying NULL,
                                      tenant_name varchar(128) DEFAULT ''::character varying NULL,
                                      tenant_desc varchar(256) NULL,
                                      create_source varchar(32) NULL,
                                      gmt_create int8 NOT NULL,
                                      gmt_modified int8 NOT NULL,
                                      CONSTRAINT idx_20537_primary PRIMARY KEY (id)
);
CREATE INDEX idx_20537_idx_tenant_id ON tenant_info USING btree (tenant_id);
CREATE UNIQUE INDEX idx_20537_uk_tenant_info_kptenantid ON tenant_info USING btree (kp, tenant_id);


-- users definition

-- Drop table

-- DROP TABLE users;

CREATE TABLE users (
                                username varchar(50) NOT NULL,
                                "password" varchar(500) NOT NULL,
                                enabled bool NOT NULL,
                                CONSTRAINT idx_20545_primary PRIMARY KEY (username)
);


INSERT INTO config_info (data_id,group_id,"content",md5,gmt_create,gmt_modified,src_user,src_ip,app_name,tenant_id,c_desc,c_use,effect,"type",c_schema,encrypted_data_key) VALUES
                                                                                                                                                                                        ('application-dev.yml','DEFAULT_GROUP','spring:
  autoconfigure:
    exclude: com.alibaba.druid.spring.boot.autoconfigure.DruidDataSourceAutoConfigure

# feign 配置
feign:
  sentinel:
    enabled: true
  okhttp:
    enabled: true
  httpclient:
    enabled: false
  client:
    config:
      default:
        connectTimeout: 10000
        readTimeout: 10000
  compression:
    request:
      enabled: true
      min-request-size: 8192
    response:
      enabled: true

# 暴露监控端点
management:
  endpoints:
    web:
      exposure:
        include: ''*''
','9928f41dfb10386ad38b3254af5692e0','2025-01-08 15:32:24.948+08','2025-01-08 15:32:24.948+08',NULL,'127.0.0.1','','rsmonitoring','通用配置',NULL,NULL,'yaml',NULL,''),
                                                                                                                                                                                        ('ruoyi-gateway-dev.yml','DEFAULT_GROUP','spring:
  redis:
    host: localhost
    port: 6379
    password:
  cloud:
    gateway:
      discovery:
        locator:
          lowerCaseServiceId: true
          enabled: true
      routes:
        # 认证中心
        - id: ruoyi-auth
          uri: lb://ruoyi-auth
          predicates:
            - Path=/auth/**
          filters:
            # 验证码处理
            - CacheRequestFilter
            - ValidateCodeFilter
            - StripPrefix=1
        # 代码生成
        - id: ruoyi-gen
          uri: lb://ruoyi-gen
          predicates:
            - Path=/code/**
          filters:
            - StripPrefix=1
        # 定时任务
        - id: ruoyi-job
          uri: lb://ruoyi-job
          predicates:
            - Path=/schedule/**
          filters:
            - StripPrefix=1
        # 系统模块
        - id: ruoyi-system
          uri: lb://ruoyi-system
          predicates:
            - Path=/system/**
          filters:
            - StripPrefix=1
        # 文件服务
        - id: ruoyi-file
          uri: lb://ruoyi-file
          predicates:
            - Path=/file/**
          filters:
            - StripPrefix=1

# 安全配置
security:
  # 验证码
  captcha:
    enabled: true
    type: math
  # 防止XSS攻击
  xss:
    enabled: true
    excludeUrls:
      - /system/notice

  # 不校验白名单
  ignore:
    whites:
      - /auth/logout
      - /auth/login
      - /auth/register
      - /*/v2/api-docs
      - /*/v3/api-docs
      - /csrf

# springdoc配置
springdoc:
  webjars:
    # 访问前缀
    prefix:
','4d329eb08a941a8dd9d26f542c6ac6c5','2025-01-08 15:32:24.96+08','2025-01-08 15:32:24.96+08',NULL,'127.0.0.1','','rsmonitoring','网关模块',NULL,NULL,'yaml',NULL,''),
                                                                                                                                                                                        ('ruoyi-auth-dev.yml','DEFAULT_GROUP','spring:
  redis:
    host: localhost
    port: 6379
    password:
','a03e7632a0a74520eeb4fbedd6d82d97','2025-01-08 15:32:24.967+08','2025-01-08 15:32:24.967+08',NULL,'127.0.0.1','','rsmonitoring','认证中心',NULL,NULL,'yaml',NULL,''),
                                                                                                                                                                                        ('ruoyi-monitor-dev.yml','DEFAULT_GROUP','# spring
spring:
  security:
    user:
      name: ruoyi
      password: 123456
  boot:
    admin:
      ui:
        title: 若依服务状态监控
','6f122fd2bfb8d45f858e7d6529a9cd44','2025-01-08 15:32:24.973+08','2025-01-08 15:32:24.973+08',NULL,'127.0.0.1','','rsmonitoring','监控中心',NULL,NULL,'yaml',NULL,''),
                                                                                                                                                                                        ('ruoyi-file-dev.yml','DEFAULT_GROUP','# 本地文件上传
file:
    domain: http://127.0.0.1:9300
    path: D:/ruoyi/uploadPath
    prefix: /statics

# FastDFS配置
fdfs:
  domain: http://8.129.231.12
  soTimeout: 3000
  connectTimeout: 2000
  trackerList: 8.129.231.12:22122

# Minio配置
minio:
  url: http://8.129.231.12:9000
  accessKey: minioadmin
  secretKey: minioadmin
  bucketName: test','5382b93f3d8059d6068c0501fdd41195','2025-01-08 15:32:25.002+08','2025-01-08 15:32:25.002+08',NULL,'127.0.0.1','','rsmonitoring','文件服务',NULL,NULL,'yaml',NULL,''),
                                                                                                                                                                                        ('ruoyi-gen-dev.yml','DEFAULT_GROUP','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.gen.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''代码生成接口文档''
    # 描述
    description: ''代码生成接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip

# 代码生成
gen:
  # 作者
  author: ruoyi
  # 默认生成包路径 system 需改成自己的模块名称 如 system monitor tool
  packageName: com.ruoyi.system
  # 自动去除表前缀，默认是false
  autoRemovePre: false
  # 表前缀（生成类名不会包含表前缀，多个用逗号分隔）
  tablePrefix: sys_
  # 是否允许生成文件覆盖到本地（自定义路径），默认不允许
  allowOverwrite: false','adaffd35363045dacb964ff6597b3f89','2025-01-08 15:32:24.988+08','2025-01-08 17:15:16.461+08','nacos','0:0:0:0:0:0:0:1','','rsmonitoring','代码生成','','','yaml','',''),
                                                                                                                                                                                        ('ruoyi-job-dev.yml','DEFAULT_GROUP','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','2bad0f01e4b408ea949909cbbf3732ec','2025-01-08 15:32:24.995+08','2025-01-08 17:28:41.594+08','nacos','0:0:0:0:0:0:0:1','','rsmonitoring','定时任务','','','yaml','',''),
                                                                                                                                                                                        ('sentinel-ruoyi-gateway','DEFAULT_GROUP','[
    {
        "resource": "ruoyi-auth",
        "count": 500,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-system",
        "count": 1000,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-gen",
        "count": 200,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-job",
        "count": 300,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    }
]','9f3a3069261598f74220bc47958ec252','2025-01-08 15:32:25.008+08','2025-01-08 15:32:25.008+08',NULL,'127.0.0.1','','rsmonitoring','限流策略',NULL,NULL,'json',NULL,''),
                                                                                                                                                                                        ('ruoyi-system-dev.yml','DEFAULT_GROUP','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          # master:
          #   driver-class-name: com.mysql.cj.jdbc.Driver
          #   url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
          #   username: root
          #   password: password
          master:
            driver-class-name: org.postgresql.Driver
            url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
            username: postgres
            password: postgis
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','f16150ad0c2d77bdb1361de3c1c31515','2025-01-08 15:32:24.98+08','2025-01-08 17:07:33.066+08','nacos','0:0:0:0:0:0:0:1','','rsmonitoring','系统模块','','','yaml','',''),
                                                                                                                                                                                        ('application-dev.yml','DEFAULT_GROUP','spring:
  autoconfigure:
    exclude: com.alibaba.druid.spring.boot.autoconfigure.DruidDataSourceAutoConfigure

# feign 配置
feign:
  sentinel:
    enabled: true
  okhttp:
    enabled: true
  httpclient:
    enabled: false
  client:
    config:
      default:
        connectTimeout: 10000
        readTimeout: 10000
  compression:
    request:
      enabled: true
      min-request-size: 8192
    response:
      enabled: true

# 暴露监控端点
management:
  endpoints:
    web:
      exposure:
        include: ''*''
','9928f41dfb10386ad38b3254af5692e0','2025-01-09 08:39:13.821+08','2025-01-09 08:39:13.821+08',NULL,'0:0:0:0:0:0:0:1','','siwei',NULL,NULL,NULL,'yaml',NULL,'');
INSERT INTO config_info (data_id,group_id,"content",md5,gmt_create,gmt_modified,src_user,src_ip,app_name,tenant_id,c_desc,c_use,effect,"type",c_schema,encrypted_data_key) VALUES
                                                                                                                                                                                        ('sentinel-ruoyi-gateway','DEFAULT_GROUP','[
    {
        "resource": "ruoyi-auth",
        "count": 500,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-system",
        "count": 1000,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-gen",
        "count": 200,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-job",
        "count": 300,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    }
]','9f3a3069261598f74220bc47958ec252','2025-01-09 08:39:14.105+08','2025-01-09 08:39:14.105+08',NULL,'0:0:0:0:0:0:0:1','','siwei',NULL,NULL,NULL,'text',NULL,''),
                                                                                                                                                                                        ('siwei-auth-dev.yml','DEFAULT_GROUP','spring:
  redis:
    host: localhost
    port: 6379
    password:
','20be3cc71833cd1e62fb4792ef83332b','2025-01-09 09:29:20.414+08','2025-01-09 09:29:20.414+08','nacos','0:0:0:0:0:0:0:1','','siwei',NULL,NULL,NULL,'yaml',NULL,''),
                                                                                                                                                                                        ('siwei-system-dev.yml','DEFAULT_GROUP','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          # master:
          #   driver-class-name: com.mysql.cj.jdbc.Driver
          #   url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
          #   username: root
          #   password: password
          master:
            driver-class-name: org.postgresql.Driver
            url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
            username: postgres
            password: postgis
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.siwei.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','769ccb532762cd90c88920f10ebce06c','2025-01-09 08:42:55.729+08','2025-01-09 10:27:33.279+08','nacos','0:0:0:0:0:0:0:1','','siwei','','','','yaml','',''),
                                                                                                                                                                                        ('siwei-file-dev.yml','DEFAULT_GROUP','# 本地文件上传
file:
    domain: http://127.0.0.1:9300
    path: D:/ruoyi/uploadPath
    prefix: /statics

# FastDFS配置
fdfs:
  domain: http://8.129.231.12
  soTimeout: 3000
  connectTimeout: 2000
  trackerList: 8.129.231.12:22122

# Minio配置
minio:
  url: http://8.129.231.12:9000
  accessKey: minioadmin
  secretKey: minioadmin
  bucketName: test','5382b93f3d8059d6068c0501fdd41195','2025-01-09 11:12:32.23+08','2025-01-09 11:12:32.23+08','nacos','0:0:0:0:0:0:0:1','','siwei',NULL,NULL,NULL,'text',NULL,''),
                                                                                                                                                                                        ('siwei-job-dev.yml','DEFAULT_GROUP','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.siwei.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','3f01395601b2099914b52427e288ab98','2025-01-09 11:19:06.331+08','2025-01-09 11:19:06.331+08','nacos','0:0:0:0:0:0:0:1','','siwei',NULL,NULL,NULL,'yaml',NULL,''),
                                                                                                                                                                                        ('siwei-monitor-dev.yml','DEFAULT_GROUP','# spring
spring:
  security:
    user:
      name: siwei
      password: 123456
  boot:
    admin:
      ui:
        title: 若依服务状态监控
','2e1bb8d9ed9c6e404094316b311db2ea','2025-01-09 13:47:04.028+08','2025-01-09 13:47:04.028+08','nacos','0:0:0:0:0:0:0:1','','siwei',NULL,NULL,NULL,'yaml',NULL,''),
                                                                                                                                                                                        ('siwei-gateway-dev.yml','DEFAULT_GROUP','spring:
  redis:
    host: localhost
    port: 6379
    password:
  cloud:
    gateway:
      discovery:
        locator:
          lowerCaseServiceId: true
          enabled: true
      routes:
        # 认证中心
        - id: siwei-auth
          uri: lb://siwei-auth
          predicates:
            - Path=/auth/**
          filters:
            # 验证码处理
            - CacheRequestFilter
            - ValidateCodeFilter
            - StripPrefix=1
        # 定时任务
        - id: siwei-job
          uri: lb://siwei-job
          predicates:
            - Path=/schedule/**
          filters:
            - StripPrefix=1
        # 系统模块
        - id: siwei-system
          uri: lb://siwei-system
          predicates:
            - Path=/system/**
          filters:
            - StripPrefix=1
        # 文件服务
        - id: siwei-file
          uri: lb://siwei-file
          predicates:
            - Path=/file/**
          filters:
            - StripPrefix=1

# 安全配置
security:
  # 验证码
  captcha:
    enabled: true
    type: math
  # 防止XSS攻击
  xss:
    enabled: true
    excludeUrls:
      - /system/notice

  # 不校验白名单
  ignore:
    whites:
      - /auth/logout
      - /auth/login
      - /auth/register
      - /*/v2/api-docs
      - /*/v3/api-docs
      - /csrf

# springdoc配置
springdoc:
  webjars:
    # 访问前缀
    prefix:
','f460df1d1d6f5ee202eb3db503c4608f','2025-01-09 09:46:34.237+08','2025-01-09 14:36:12.949+08','nacos','0:0:0:0:0:0:0:1','','siwei','','','','yaml','','');
INSERT INTO his_config_info (id,data_id,group_id,app_name,"content",md5,gmt_create,gmt_modified,src_user,src_ip,op_type,tenant_id,encrypted_data_key) VALUES
                                                                                                                                                                   (0,'12','DEFAULT_GROUP','','12','c20ad4d76fe97759aa27a0c99bff6710','2025-01-08 22:30:59+08','2025-01-08 14:31:00+08','nacos','127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (0,'1','DEFAULT_GROUP','','2','c81e728d9d4c2f636f067f89cc14862c','2025-01-08 15:31:02.829349+08','2025-01-08 15:31:01.733+08','nacos','127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (0,'application-dev.yml','DEFAULT_GROUP','','spring:
  autoconfigure:
    exclude: com.alibaba.druid.spring.boot.autoconfigure.DruidDataSourceAutoConfigure

# feign 配置
feign:
  sentinel:
    enabled: true
  okhttp:
    enabled: true
  httpclient:
    enabled: false
  client:
    config:
      default:
        connectTimeout: 10000
        readTimeout: 10000
  compression:
    request:
      enabled: true
      min-request-size: 8192
    response:
      enabled: true

# 暴露监控端点
management:
  endpoints:
    web:
      exposure:
        include: ''*''
','9928f41dfb10386ad38b3254af5692e0','2025-01-08 15:31:12.113117+08','2025-01-08 15:31:11.002+08',NULL,'127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (0,'ruoyi-gateway-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
  cloud:
    gateway:
      discovery:
        locator:
          lowerCaseServiceId: true
          enabled: true
      routes:
        # 认证中心
        - id: ruoyi-auth
          uri: lb://ruoyi-auth
          predicates:
            - Path=/auth/**
          filters:
            # 验证码处理
            - CacheRequestFilter
            - ValidateCodeFilter
            - StripPrefix=1
        # 代码生成
        - id: ruoyi-gen
          uri: lb://ruoyi-gen
          predicates:
            - Path=/code/**
          filters:
            - StripPrefix=1
        # 定时任务
        - id: ruoyi-job
          uri: lb://ruoyi-job
          predicates:
            - Path=/schedule/**
          filters:
            - StripPrefix=1
        # 系统模块
        - id: ruoyi-system
          uri: lb://ruoyi-system
          predicates:
            - Path=/system/**
          filters:
            - StripPrefix=1
        # 文件服务
        - id: ruoyi-file
          uri: lb://ruoyi-file
          predicates:
            - Path=/file/**
          filters:
            - StripPrefix=1

# 安全配置
security:
  # 验证码
  captcha:
    enabled: true
    type: math
  # 防止XSS攻击
  xss:
    enabled: true
    excludeUrls:
      - /system/notice

  # 不校验白名单
  ignore:
    whites:
      - /auth/logout
      - /auth/login
      - /auth/register
      - /*/v2/api-docs
      - /*/v3/api-docs
      - /csrf

# springdoc配置
springdoc:
  webjars:
    # 访问前缀
    prefix:
','4d329eb08a941a8dd9d26f542c6ac6c5','2025-01-08 15:31:12.122045+08','2025-01-08 15:31:11.011+08',NULL,'127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (0,'ruoyi-auth-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
','a03e7632a0a74520eeb4fbedd6d82d97','2025-01-08 15:31:12.129456+08','2025-01-08 15:31:11.019+08',NULL,'127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (0,'ruoyi-monitor-dev.yml','DEFAULT_GROUP','','# spring
spring:
  security:
    user:
      name: ruoyi
      password: 123456
  boot:
    admin:
      ui:
        title: 若依服务状态监控
','6f122fd2bfb8d45f858e7d6529a9cd44','2025-01-08 15:31:12.136292+08','2025-01-08 15:31:11.025+08',NULL,'127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (0,'ruoyi-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1 FROM DUAL
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          master:
            driver-class-name: com.mysql.cj.jdbc.Driver
            url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
            username: root
            password: password
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','786c7daf4543411fc65c3e48dfb15243','2025-01-08 15:31:12.148136+08','2025-01-08 15:31:11.036+08',NULL,'127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (0,'ruoyi-gen-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: com.mysql.cj.jdbc.Driver
    url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
    username: root
    password: password

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.gen.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''代码生成接口文档''
    # 描述
    description: ''代码生成接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip

# 代码生成
gen:
  # 作者
  author: ruoyi
  # 默认生成包路径 system 需改成自己的模块名称 如 system monitor tool
  packageName: com.ruoyi.system
  # 自动去除表前缀，默认是false
  autoRemovePre: false
  # 表前缀（生成类名不会包含表前缀，多个用逗号分隔）
  tablePrefix: sys_
  # 是否允许生成文件覆盖到本地（自定义路径），默认不允许
  allowOverwrite: false','43d807aa0a4accbb193b6dc7e38ac8a3','2025-01-08 15:31:12.155463+08','2025-01-08 15:31:11.044+08',NULL,'127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (0,'ruoyi-job-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: com.mysql.cj.jdbc.Driver
    url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
    username: root
    password: password

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','f78483f845777335b9ed4a9f84758848','2025-01-08 15:31:12.162596+08','2025-01-08 15:31:11.051+08',NULL,'127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (0,'ruoyi-file-dev.yml','DEFAULT_GROUP','','# 本地文件上传
file:
    domain: http://127.0.0.1:9300
    path: D:/ruoyi/uploadPath
    prefix: /statics

# FastDFS配置
fdfs:
  domain: http://8.129.231.12
  soTimeout: 3000
  connectTimeout: 2000
  trackerList: 8.129.231.12:22122

# Minio配置
minio:
  url: http://8.129.231.12:9000
  accessKey: minioadmin
  secretKey: minioadmin
  bucketName: test','5382b93f3d8059d6068c0501fdd41195','2025-01-08 15:31:12.169417+08','2025-01-08 15:31:11.059+08',NULL,'127.0.0.1','I         ','ceshi01','');
INSERT INTO his_config_info (id,data_id,group_id,app_name,"content",md5,gmt_create,gmt_modified,src_user,src_ip,op_type,tenant_id,encrypted_data_key) VALUES
                                                                                                                                                                   (0,'sentinel-ruoyi-gateway','DEFAULT_GROUP','','[
    {
        "resource": "ruoyi-auth",
        "count": 500,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-system",
        "count": 1000,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-gen",
        "count": 200,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-job",
        "count": 300,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    }
]','9f3a3069261598f74220bc47958ec252','2025-01-08 15:31:12.17702+08','2025-01-08 15:31:11.066+08',NULL,'127.0.0.1','I         ','ceshi01',''),
                                                                                                                                                                   (1,'12','DEFAULT_GROUP','','12','c20ad4d76fe97759aa27a0c99bff6710','2025-01-08 15:31:22.274735+08','2025-01-08 15:31:21.156+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (2,'1','DEFAULT_GROUP','','2','c81e728d9d4c2f636f067f89cc14862c','2025-01-08 15:31:26.30891+08','2025-01-08 15:31:25.191+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (3,'application-dev.yml','DEFAULT_GROUP','','spring:
  autoconfigure:
    exclude: com.alibaba.druid.spring.boot.autoconfigure.DruidDataSourceAutoConfigure

# feign 配置
feign:
  sentinel:
    enabled: true
  okhttp:
    enabled: true
  httpclient:
    enabled: false
  client:
    config:
      default:
        connectTimeout: 10000
        readTimeout: 10000
  compression:
    request:
      enabled: true
      min-request-size: 8192
    response:
      enabled: true

# 暴露监控端点
management:
  endpoints:
    web:
      exposure:
        include: ''*''
','9928f41dfb10386ad38b3254af5692e0','2025-01-08 15:31:52.804971+08','2025-01-08 15:31:51.689+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (4,'ruoyi-gateway-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
  cloud:
    gateway:
      discovery:
        locator:
          lowerCaseServiceId: true
          enabled: true
      routes:
        # 认证中心
        - id: ruoyi-auth
          uri: lb://ruoyi-auth
          predicates:
            - Path=/auth/**
          filters:
            # 验证码处理
            - CacheRequestFilter
            - ValidateCodeFilter
            - StripPrefix=1
        # 代码生成
        - id: ruoyi-gen
          uri: lb://ruoyi-gen
          predicates:
            - Path=/code/**
          filters:
            - StripPrefix=1
        # 定时任务
        - id: ruoyi-job
          uri: lb://ruoyi-job
          predicates:
            - Path=/schedule/**
          filters:
            - StripPrefix=1
        # 系统模块
        - id: ruoyi-system
          uri: lb://ruoyi-system
          predicates:
            - Path=/system/**
          filters:
            - StripPrefix=1
        # 文件服务
        - id: ruoyi-file
          uri: lb://ruoyi-file
          predicates:
            - Path=/file/**
          filters:
            - StripPrefix=1

# 安全配置
security:
  # 验证码
  captcha:
    enabled: true
    type: math
  # 防止XSS攻击
  xss:
    enabled: true
    excludeUrls:
      - /system/notice

  # 不校验白名单
  ignore:
    whites:
      - /auth/logout
      - /auth/login
      - /auth/register
      - /*/v2/api-docs
      - /*/v3/api-docs
      - /csrf

# springdoc配置
springdoc:
  webjars:
    # 访问前缀
    prefix:
','4d329eb08a941a8dd9d26f542c6ac6c5','2025-01-08 15:31:52.804971+08','2025-01-08 15:31:51.689+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (5,'ruoyi-auth-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
','a03e7632a0a74520eeb4fbedd6d82d97','2025-01-08 15:31:52.804971+08','2025-01-08 15:31:51.689+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (6,'ruoyi-monitor-dev.yml','DEFAULT_GROUP','','# spring
spring:
  security:
    user:
      name: ruoyi
      password: 123456
  boot:
    admin:
      ui:
        title: 若依服务状态监控
','6f122fd2bfb8d45f858e7d6529a9cd44','2025-01-08 15:31:52.804971+08','2025-01-08 15:31:51.689+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (7,'ruoyi-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1 FROM DUAL
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          master:
            driver-class-name: com.mysql.cj.jdbc.Driver
            url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
            username: root
            password: password
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','786c7daf4543411fc65c3e48dfb15243','2025-01-08 15:31:52.804971+08','2025-01-08 15:31:51.689+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (18,'ruoyi-job-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: com.mysql.cj.jdbc.Driver
    url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
    username: root
    password: password

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','d69276c47406a026588ad6a28d510536','2025-01-08 17:28:42.820813+08','2025-01-08 17:28:41.596+08','nacos','0:0:0:0:0:0:0:1','U         ','rsmonitoring',''),
                                                                                                                                                                   (8,'ruoyi-gen-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: com.mysql.cj.jdbc.Driver
    url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
    username: root
    password: password

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.gen.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''代码生成接口文档''
    # 描述
    description: ''代码生成接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip

# 代码生成
gen:
  # 作者
  author: ruoyi
  # 默认生成包路径 system 需改成自己的模块名称 如 system monitor tool
  packageName: com.ruoyi.system
  # 自动去除表前缀，默认是false
  autoRemovePre: false
  # 表前缀（生成类名不会包含表前缀，多个用逗号分隔）
  tablePrefix: sys_
  # 是否允许生成文件覆盖到本地（自定义路径），默认不允许
  allowOverwrite: false','43d807aa0a4accbb193b6dc7e38ac8a3','2025-01-08 15:31:52.804971+08','2025-01-08 15:31:51.689+08','nacos','127.0.0.1','D         ','ceshi01','');
INSERT INTO his_config_info (id,data_id,group_id,app_name,"content",md5,gmt_create,gmt_modified,src_user,src_ip,op_type,tenant_id,encrypted_data_key) VALUES
                                                                                                                                                                   (9,'ruoyi-job-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: com.mysql.cj.jdbc.Driver
    url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
    username: root
    password: password

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','f78483f845777335b9ed4a9f84758848','2025-01-08 15:31:52.804971+08','2025-01-08 15:31:51.689+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (10,'ruoyi-file-dev.yml','DEFAULT_GROUP','','# 本地文件上传
file:
    domain: http://127.0.0.1:9300
    path: D:/ruoyi/uploadPath
    prefix: /statics

# FastDFS配置
fdfs:
  domain: http://8.129.231.12
  soTimeout: 3000
  connectTimeout: 2000
  trackerList: 8.129.231.12:22122

# Minio配置
minio:
  url: http://8.129.231.12:9000
  accessKey: minioadmin
  secretKey: minioadmin
  bucketName: test','5382b93f3d8059d6068c0501fdd41195','2025-01-08 15:31:52.804971+08','2025-01-08 15:31:51.689+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (11,'sentinel-ruoyi-gateway','DEFAULT_GROUP','','[
    {
        "resource": "ruoyi-auth",
        "count": 500,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-system",
        "count": 1000,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-gen",
        "count": 200,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-job",
        "count": 300,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    }
]','9f3a3069261598f74220bc47958ec252','2025-01-08 15:31:52.804971+08','2025-01-08 15:31:51.689+08','nacos','127.0.0.1','D         ','ceshi01',''),
                                                                                                                                                                   (0,'application-dev.yml','DEFAULT_GROUP','','spring:
  autoconfigure:
    exclude: com.alibaba.druid.spring.boot.autoconfigure.DruidDataSourceAutoConfigure

# feign 配置
feign:
  sentinel:
    enabled: true
  okhttp:
    enabled: true
  httpclient:
    enabled: false
  client:
    config:
      default:
        connectTimeout: 10000
        readTimeout: 10000
  compression:
    request:
      enabled: true
      min-request-size: 8192
    response:
      enabled: true

# 暴露监控端点
management:
  endpoints:
    web:
      exposure:
        include: ''*''
','9928f41dfb10386ad38b3254af5692e0','2025-01-08 15:32:26.062168+08','2025-01-08 15:32:24.951+08',NULL,'127.0.0.1','I         ','rsmonitoring',''),
                                                                                                                                                                   (0,'ruoyi-gateway-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
  cloud:
    gateway:
      discovery:
        locator:
          lowerCaseServiceId: true
          enabled: true
      routes:
        # 认证中心
        - id: ruoyi-auth
          uri: lb://ruoyi-auth
          predicates:
            - Path=/auth/**
          filters:
            # 验证码处理
            - CacheRequestFilter
            - ValidateCodeFilter
            - StripPrefix=1
        # 代码生成
        - id: ruoyi-gen
          uri: lb://ruoyi-gen
          predicates:
            - Path=/code/**
          filters:
            - StripPrefix=1
        # 定时任务
        - id: ruoyi-job
          uri: lb://ruoyi-job
          predicates:
            - Path=/schedule/**
          filters:
            - StripPrefix=1
        # 系统模块
        - id: ruoyi-system
          uri: lb://ruoyi-system
          predicates:
            - Path=/system/**
          filters:
            - StripPrefix=1
        # 文件服务
        - id: ruoyi-file
          uri: lb://ruoyi-file
          predicates:
            - Path=/file/**
          filters:
            - StripPrefix=1

# 安全配置
security:
  # 验证码
  captcha:
    enabled: true
    type: math
  # 防止XSS攻击
  xss:
    enabled: true
    excludeUrls:
      - /system/notice

  # 不校验白名单
  ignore:
    whites:
      - /auth/logout
      - /auth/login
      - /auth/register
      - /*/v2/api-docs
      - /*/v3/api-docs
      - /csrf

# springdoc配置
springdoc:
  webjars:
    # 访问前缀
    prefix:
','4d329eb08a941a8dd9d26f542c6ac6c5','2025-01-08 15:32:26.074312+08','2025-01-08 15:32:24.962+08',NULL,'127.0.0.1','I         ','rsmonitoring',''),
                                                                                                                                                                   (0,'ruoyi-auth-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
','a03e7632a0a74520eeb4fbedd6d82d97','2025-01-08 15:32:26.080499+08','2025-01-08 15:32:24.969+08',NULL,'127.0.0.1','I         ','rsmonitoring',''),
                                                                                                                                                                   (0,'ruoyi-monitor-dev.yml','DEFAULT_GROUP','','# spring
spring:
  security:
    user:
      name: ruoyi
      password: 123456
  boot:
    admin:
      ui:
        title: 若依服务状态监控
','6f122fd2bfb8d45f858e7d6529a9cd44','2025-01-08 15:32:26.08712+08','2025-01-08 15:32:24.975+08',NULL,'127.0.0.1','I         ','rsmonitoring',''),
                                                                                                                                                                   (0,'ruoyi-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1 FROM DUAL
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          master:
            driver-class-name: com.mysql.cj.jdbc.Driver
            url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
            username: root
            password: password
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','786c7daf4543411fc65c3e48dfb15243','2025-01-08 15:32:26.094152+08','2025-01-08 15:32:24.982+08',NULL,'127.0.0.1','I         ','rsmonitoring',''),
                                                                                                                                                                   (0,'ruoyi-gen-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: com.mysql.cj.jdbc.Driver
    url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
    username: root
    password: password

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.gen.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''代码生成接口文档''
    # 描述
    description: ''代码生成接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip

# 代码生成
gen:
  # 作者
  author: ruoyi
  # 默认生成包路径 system 需改成自己的模块名称 如 system monitor tool
  packageName: com.ruoyi.system
  # 自动去除表前缀，默认是false
  autoRemovePre: false
  # 表前缀（生成类名不会包含表前缀，多个用逗号分隔）
  tablePrefix: sys_
  # 是否允许生成文件覆盖到本地（自定义路径），默认不允许
  allowOverwrite: false','43d807aa0a4accbb193b6dc7e38ac8a3','2025-01-08 15:32:26.101974+08','2025-01-08 15:32:24.99+08',NULL,'127.0.0.1','I         ','rsmonitoring',''),
                                                                                                                                                                   (0,'ruoyi-job-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: com.mysql.cj.jdbc.Driver
    url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
    username: root
    password: password

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','f78483f845777335b9ed4a9f84758848','2025-01-08 15:32:26.109507+08','2025-01-08 15:32:24.997+08',NULL,'127.0.0.1','I         ','rsmonitoring','');
INSERT INTO his_config_info (id,data_id,group_id,app_name,"content",md5,gmt_create,gmt_modified,src_user,src_ip,op_type,tenant_id,encrypted_data_key) VALUES
                                                                                                                                                                   (0,'ruoyi-file-dev.yml','DEFAULT_GROUP','','# 本地文件上传
file:
    domain: http://127.0.0.1:9300
    path: D:/ruoyi/uploadPath
    prefix: /statics

# FastDFS配置
fdfs:
  domain: http://8.129.231.12
  soTimeout: 3000
  connectTimeout: 2000
  trackerList: 8.129.231.12:22122

# Minio配置
minio:
  url: http://8.129.231.12:9000
  accessKey: minioadmin
  secretKey: minioadmin
  bucketName: test','5382b93f3d8059d6068c0501fdd41195','2025-01-08 15:32:26.115705+08','2025-01-08 15:32:25.003+08',NULL,'127.0.0.1','I         ','rsmonitoring',''),
                                                                                                                                                                   (0,'sentinel-ruoyi-gateway','DEFAULT_GROUP','','[
    {
        "resource": "ruoyi-auth",
        "count": 500,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-system",
        "count": 1000,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-gen",
        "count": 200,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-job",
        "count": 300,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    }
]','9f3a3069261598f74220bc47958ec252','2025-01-08 15:32:26.122244+08','2025-01-08 15:32:25.01+08',NULL,'127.0.0.1','I         ','rsmonitoring',''),
                                                                                                                                                                   (16,'ruoyi-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1 FROM DUAL
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          master:
            driver-class-name: com.mysql.cj.jdbc.Driver
            url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
            username: root
            password: password
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','786c7daf4543411fc65c3e48dfb15243','2025-01-08 15:50:55.812504+08','2025-01-08 15:50:54.674+08','nacos','127.0.0.1','U         ','rsmonitoring',''),
                                                                                                                                                                   (16,'ruoyi-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          # master:
          #   driver-class-name: com.mysql.cj.jdbc.Driver
          #   url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
          #   username: root
          #   password: password
          master:
            driver-class-name: org.postgresql.Driver
            url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
            username: postgres
            password: postgis
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','44b461bc529cb2ba64d4193e710e0e47','2025-01-08 16:21:26.092275+08','2025-01-08 16:21:24.871+08','nacos','127.0.0.1','U         ','rsmonitoring',''),
                                                                                                                                                                   (16,'ruoyi-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          # master:
          #   driver-class-name: com.mysql.cj.jdbc.Driver
          #   url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
          #   username: root
          #   password: password
          master:
            driver-class-name: org.postgresql.Driver
            url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
            username: postgres
            password: postgis
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/system/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','8ddc112333af6c7ce872db65941e6d19','2025-01-08 17:07:34.287416+08','2025-01-08 17:07:33.075+08','nacos','0:0:0:0:0:0:0:1','U         ','rsmonitoring',''),
                                                                                                                                                                   (17,'ruoyi-gen-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: com.mysql.cj.jdbc.Driver
    url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
    username: root
    password: password

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.gen.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''代码生成接口文档''
    # 描述
    description: ''代码生成接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip

# 代码生成
gen:
  # 作者
  author: ruoyi
  # 默认生成包路径 system 需改成自己的模块名称 如 system monitor tool
  packageName: com.ruoyi.system
  # 自动去除表前缀，默认是false
  autoRemovePre: false
  # 表前缀（生成类名不会包含表前缀，多个用逗号分隔）
  tablePrefix: sys_
  # 是否允许生成文件覆盖到本地（自定义路径），默认不允许
  allowOverwrite: false','43d807aa0a4accbb193b6dc7e38ac8a3','2025-01-08 17:12:38.996543+08','2025-01-08 17:12:37.775+08','nacos','0:0:0:0:0:0:0:1','U         ','rsmonitoring',''),
                                                                                                                                                                   (17,'ruoyi-gen-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.gen.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''代码生成接口文档''
    # 描述
    description: ''代码生成接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip

# 代码生成
gen:
  # 作者
  author: ruoyi
  # 默认生成包路径 system 需改成自己的模块名称 如 system monitor tool
  packageName: com.ruoyi.system
  # 自动去除表前缀，默认是false
  autoRemovePre: false
  # 表前缀（生成类名不会包含表前缀，多个用逗号分隔）
  tablePrefix: sys_
  # 是否允许生成文件覆盖到本地（自定义路径），默认不允许
  allowOverwrite: false','a75c93ff11715f5c9fffaa34aaa07c40','2025-01-08 17:15:17.683702+08','2025-01-08 17:15:16.463+08','nacos','0:0:0:0:0:0:0:1','U         ','rsmonitoring',''),
                                                                                                                                                                   (18,'ruoyi-job-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: com.mysql.cj.jdbc.Driver
    url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
    username: root
    password: password

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','f78483f845777335b9ed4a9f84758848','2025-01-08 17:27:56.134696+08','2025-01-08 17:27:54.911+08','nacos','0:0:0:0:0:0:0:1','U         ','rsmonitoring',''),
                                                                                                                                                                   (0,'application-dev.yml','DEFAULT_GROUP','','spring:
  autoconfigure:
    exclude: com.alibaba.druid.spring.boot.autoconfigure.DruidDataSourceAutoConfigure

# feign 配置
feign:
  sentinel:
    enabled: true
  okhttp:
    enabled: true
  httpclient:
    enabled: false
  client:
    config:
      default:
        connectTimeout: 10000
        readTimeout: 10000
  compression:
    request:
      enabled: true
      min-request-size: 8192
    response:
      enabled: true

# 暴露监控端点
management:
  endpoints:
    web:
      exposure:
        include: ''*''
','9928f41dfb10386ad38b3254af5692e0','2025-01-09 08:39:15.72183+08','2025-01-09 08:39:13.835+08',NULL,'0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (0,'ruoyi-gateway-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
  cloud:
    gateway:
      discovery:
        locator:
          lowerCaseServiceId: true
          enabled: true
      routes:
        # 认证中心
        - id: ruoyi-auth
          uri: lb://ruoyi-auth
          predicates:
            - Path=/auth/**
          filters:
            # 验证码处理
            - CacheRequestFilter
            - ValidateCodeFilter
            - StripPrefix=1
        # 代码生成
        - id: ruoyi-gen
          uri: lb://ruoyi-gen
          predicates:
            - Path=/code/**
          filters:
            - StripPrefix=1
        # 定时任务
        - id: ruoyi-job
          uri: lb://ruoyi-job
          predicates:
            - Path=/schedule/**
          filters:
            - StripPrefix=1
        # 系统模块
        - id: ruoyi-system
          uri: lb://ruoyi-system
          predicates:
            - Path=/system/**
          filters:
            - StripPrefix=1
        # 文件服务
        - id: ruoyi-file
          uri: lb://ruoyi-file
          predicates:
            - Path=/file/**
          filters:
            - StripPrefix=1

# 安全配置
security:
  # 验证码
  captcha:
    enabled: true
    type: math
  # 防止XSS攻击
  xss:
    enabled: true
    excludeUrls:
      - /system/notice

  # 不校验白名单
  ignore:
    whites:
      - /auth/logout
      - /auth/login
      - /auth/register
      - /*/v2/api-docs
      - /*/v3/api-docs
      - /csrf

# springdoc配置
springdoc:
  webjars:
    # 访问前缀
    prefix:
','4d329eb08a941a8dd9d26f542c6ac6c5','2025-01-09 08:39:15.774443+08','2025-01-09 08:39:13.877+08',NULL,'0:0:0:0:0:0:0:1','I         ','siwei','');
INSERT INTO his_config_info (id,data_id,group_id,app_name,"content",md5,gmt_create,gmt_modified,src_user,src_ip,op_type,tenant_id,encrypted_data_key) VALUES
                                                                                                                                                                   (0,'ruoyi-auth-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
','a03e7632a0a74520eeb4fbedd6d82d97','2025-01-09 08:39:15.837044+08','2025-01-09 08:39:13.941+08',NULL,'0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (0,'ruoyi-monitor-dev.yml','DEFAULT_GROUP','','# spring
spring:
  security:
    user:
      name: ruoyi
      password: 123456
  boot:
    admin:
      ui:
        title: 若依服务状态监控
','6f122fd2bfb8d45f858e7d6529a9cd44','2025-01-09 08:39:15.884367+08','2025-01-09 08:39:14+08',NULL,'0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (0,'ruoyi-file-dev.yml','DEFAULT_GROUP','','# 本地文件上传
file:
    domain: http://127.0.0.1:9300
    path: D:/ruoyi/uploadPath
    prefix: /statics

# FastDFS配置
fdfs:
  domain: http://8.129.231.12
  soTimeout: 3000
  connectTimeout: 2000
  trackerList: 8.129.231.12:22122

# Minio配置
minio:
  url: http://8.129.231.12:9000
  accessKey: minioadmin
  secretKey: minioadmin
  bucketName: test','5382b93f3d8059d6068c0501fdd41195','2025-01-09 08:39:15.930381+08','2025-01-09 08:39:14.035+08',NULL,'0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (0,'ruoyi-gen-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.gen.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''代码生成接口文档''
    # 描述
    description: ''代码生成接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip

# 代码生成
gen:
  # 作者
  author: ruoyi
  # 默认生成包路径 system 需改成自己的模块名称 如 system monitor tool
  packageName: com.ruoyi.system
  # 自动去除表前缀，默认是false
  autoRemovePre: false
  # 表前缀（生成类名不会包含表前缀，多个用逗号分隔）
  tablePrefix: sys_
  # 是否允许生成文件覆盖到本地（自定义路径），默认不允许
  allowOverwrite: false','adaffd35363045dacb964ff6597b3f89','2025-01-09 08:39:15.976125+08','2025-01-09 08:39:14.078+08',NULL,'0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (0,'ruoyi-job-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','2bad0f01e4b408ea949909cbbf3732ec','2025-01-09 08:39:15.998413+08','2025-01-09 08:39:14.1+08',NULL,'0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (0,'sentinel-ruoyi-gateway','DEFAULT_GROUP','','[
    {
        "resource": "ruoyi-auth",
        "count": 500,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-system",
        "count": 1000,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-gen",
        "count": 200,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    },
	{
        "resource": "ruoyi-job",
        "count": 300,
        "grade": 1,
        "limitApp": "default",
        "strategy": 0,
        "controlBehavior": 0
    }
]','9f3a3069261598f74220bc47958ec252','2025-01-09 08:39:16.00475+08','2025-01-09 08:39:14.107+08',NULL,'0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (0,'ruoyi-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          # master:
          #   driver-class-name: com.mysql.cj.jdbc.Driver
          #   url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
          #   username: root
          #   password: password
          master:
            driver-class-name: org.postgresql.Driver
            url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
            username: postgres
            password: postgis
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','f16150ad0c2d77bdb1361de3c1c31515','2025-01-09 08:39:16.012303+08','2025-01-09 08:39:14.114+08',NULL,'0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (0,'siwei-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: siwei
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          # master:
          #   driver-class-name: com.mysql.cj.jdbc.Driver
          #   url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
          #   username: root
          #   password: password
          master:
            driver-class-name: org.postgresql.Driver
            url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
            username: postgres
            password: postgis
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.siwei.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','4e3f8c4c251eb44c79e7d35e09279852','2025-01-09 08:42:57.633639+08','2025-01-09 08:42:55.731+08','nacos','0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (29,'ruoyi-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          # master:
          #   driver-class-name: com.mysql.cj.jdbc.Driver
          #   url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
          #   username: root
          #   password: password
          master:
            driver-class-name: org.postgresql.Driver
            url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
            username: postgres
            password: postgis
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','f16150ad0c2d77bdb1361de3c1c31515','2025-01-09 08:43:03.672998+08','2025-01-09 08:43:01.768+08','nacos','0:0:0:0:0:0:0:1','D         ','siwei',''),
                                                                                                                                                                   (30,'siwei-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: siwei
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          # master:
          #   driver-class-name: com.mysql.cj.jdbc.Driver
          #   url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
          #   username: root
          #   password: password
          master:
            driver-class-name: org.postgresql.Driver
            url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
            username: postgres
            password: postgis
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.siwei.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','4e3f8c4c251eb44c79e7d35e09279852','2025-01-09 09:00:15.892213+08','2025-01-09 09:00:13.999+08','nacos','0:0:0:0:0:0:0:1','U         ','siwei','');
INSERT INTO his_config_info (id,data_id,group_id,app_name,"content",md5,gmt_create,gmt_modified,src_user,src_ip,op_type,tenant_id,encrypted_data_key) VALUES
                                                                                                                                                                   (0,'siwei-auth-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
','20be3cc71833cd1e62fb4792ef83332b','2025-01-09 09:29:22.32101+08','2025-01-09 09:29:20.419+08','nacos','0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (23,'ruoyi-auth-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
','a03e7632a0a74520eeb4fbedd6d82d97','2025-01-09 09:30:22.080524+08','2025-01-09 09:30:20.168+08','nacos','0:0:0:0:0:0:0:1','D         ','siwei',''),
                                                                                                                                                                   (0,'siwei-gateway-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
  cloud:
    gateway:
      discovery:
        locator:
          lowerCaseServiceId: true
          enabled: true
      routes:
        # 认证中心
        - id: ruoyi-auth
          uri: lb://ruoyi-auth
          predicates:
            - Path=/auth/**
          filters:
            # 验证码处理
            - CacheRequestFilter
            - ValidateCodeFilter
            - StripPrefix=1
        # 代码生成
        - id: ruoyi-gen
          uri: lb://ruoyi-gen
          predicates:
            - Path=/code/**
          filters:
            - StripPrefix=1
        # 定时任务
        - id: ruoyi-job
          uri: lb://ruoyi-job
          predicates:
            - Path=/schedule/**
          filters:
            - StripPrefix=1
        # 系统模块
        - id: ruoyi-system
          uri: lb://ruoyi-system
          predicates:
            - Path=/system/**
          filters:
            - StripPrefix=1
        # 文件服务
        - id: ruoyi-file
          uri: lb://ruoyi-file
          predicates:
            - Path=/file/**
          filters:
            - StripPrefix=1

# 安全配置
security:
  # 验证码
  captcha:
    enabled: true
    type: math
  # 防止XSS攻击
  xss:
    enabled: true
    excludeUrls:
      - /system/notice

  # 不校验白名单
  ignore:
    whites:
      - /auth/logout
      - /auth/login
      - /auth/register
      - /*/v2/api-docs
      - /*/v3/api-docs
      - /csrf

# springdoc配置
springdoc:
  webjars:
    # 访问前缀
    prefix:
','4e5585c6a80a82b346056a00d6efe588','2025-01-09 09:46:36.179415+08','2025-01-09 09:46:34.24+08','nacos','0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (22,'ruoyi-gateway-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
  cloud:
    gateway:
      discovery:
        locator:
          lowerCaseServiceId: true
          enabled: true
      routes:
        # 认证中心
        - id: ruoyi-auth
          uri: lb://ruoyi-auth
          predicates:
            - Path=/auth/**
          filters:
            # 验证码处理
            - CacheRequestFilter
            - ValidateCodeFilter
            - StripPrefix=1
        # 代码生成
        - id: ruoyi-gen
          uri: lb://ruoyi-gen
          predicates:
            - Path=/code/**
          filters:
            - StripPrefix=1
        # 定时任务
        - id: ruoyi-job
          uri: lb://ruoyi-job
          predicates:
            - Path=/schedule/**
          filters:
            - StripPrefix=1
        # 系统模块
        - id: ruoyi-system
          uri: lb://ruoyi-system
          predicates:
            - Path=/system/**
          filters:
            - StripPrefix=1
        # 文件服务
        - id: ruoyi-file
          uri: lb://ruoyi-file
          predicates:
            - Path=/file/**
          filters:
            - StripPrefix=1

# 安全配置
security:
  # 验证码
  captcha:
    enabled: true
    type: math
  # 防止XSS攻击
  xss:
    enabled: true
    excludeUrls:
      - /system/notice

  # 不校验白名单
  ignore:
    whites:
      - /auth/logout
      - /auth/login
      - /auth/register
      - /*/v2/api-docs
      - /*/v3/api-docs
      - /csrf

# springdoc配置
springdoc:
  webjars:
    # 访问前缀
    prefix:
','4d329eb08a941a8dd9d26f542c6ac6c5','2025-01-09 09:47:20.09715+08','2025-01-09 09:47:18.152+08','nacos','0:0:0:0:0:0:0:1','D         ','siwei',''),
                                                                                                                                                                   (30,'siwei-system-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    druid:
      stat-view-servlet:
        enabled: true
        loginUsername: ruoyi
        loginPassword: 123456
    dynamic:
      druid:
        initial-size: 5
        min-idle: 5
        maxActive: 20
        maxWait: 60000
        connectTimeout: 30000
        socketTimeout: 60000
        timeBetweenEvictionRunsMillis: 60000
        minEvictableIdleTimeMillis: 300000
        validationQuery: SELECT 1
        testWhileIdle: true
        testOnBorrow: false
        testOnReturn: false
        poolPreparedStatements: true
        maxPoolPreparedStatementPerConnectionSize: 20
        filters: stat,slf4j
        connectionProperties: druid.stat.mergeSql\=true;druid.stat.slowSqlMillis\=5000
      datasource:
          # 主库数据源
          # master:
          #   driver-class-name: com.mysql.cj.jdbc.Driver
          #   url: jdbc:mysql://localhost:3306/ry-cloud?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
          #   username: root
          #   password: password
          master:
            driver-class-name: org.postgresql.Driver
            url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
            username: postgres
            password: postgis
          # 从库数据源
          # slave:
            # username:
            # password:
            # url:
            # driver-class-name:

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.system
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''系统模块接口文档''
    # 描述
    description: ''系统模块接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','f16150ad0c2d77bdb1361de3c1c31515','2025-01-09 10:27:35.221222+08','2025-01-09 10:27:33.281+08','nacos','0:0:0:0:0:0:0:1','U         ','siwei',''),
                                                                                                                                                                   (0,'siwei-file-dev.yml','DEFAULT_GROUP','','# 本地文件上传
file:
    domain: http://127.0.0.1:9300
    path: D:/ruoyi/uploadPath
    prefix: /statics

# FastDFS配置
fdfs:
  domain: http://8.129.231.12
  soTimeout: 3000
  connectTimeout: 2000
  trackerList: 8.129.231.12:22122

# Minio配置
minio:
  url: http://8.129.231.12:9000
  accessKey: minioadmin
  secretKey: minioadmin
  bucketName: test','5382b93f3d8059d6068c0501fdd41195','2025-01-09 11:12:34.213987+08','2025-01-09 11:12:32.237+08','nacos','0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (25,'ruoyi-file-dev.yml','DEFAULT_GROUP','','# 本地文件上传
file:
    domain: http://127.0.0.1:9300
    path: D:/ruoyi/uploadPath
    prefix: /statics

# FastDFS配置
fdfs:
  domain: http://8.129.231.12
  soTimeout: 3000
  connectTimeout: 2000
  trackerList: 8.129.231.12:22122

# Minio配置
minio:
  url: http://8.129.231.12:9000
  accessKey: minioadmin
  secretKey: minioadmin
  bucketName: test','5382b93f3d8059d6068c0501fdd41195','2025-01-09 11:15:00.045738+08','2025-01-09 11:14:58.056+08','nacos','0:0:0:0:0:0:0:1','D         ','siwei',''),
                                                                                                                                                                   (27,'ruoyi-job-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','2bad0f01e4b408ea949909cbbf3732ec','2025-01-09 11:17:35.818934+08','2025-01-09 11:17:33.835+08','nacos','0:0:0:0:0:0:0:1','U         ','siwei',''),
                                                                                                                                                                   (0,'siwei-job-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.siwei.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','3f01395601b2099914b52427e288ab98','2025-01-09 11:19:08.32646+08','2025-01-09 11:19:06.335+08','nacos','0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (27,'ruoyi-job-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.siwei.job.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''定时任务接口文档''
    # 描述
    description: ''定时任务接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip
','27b1943f8e1683983ea511bc7a6f7076','2025-01-09 13:45:17.460433+08','2025-01-09 13:45:17.415+08','nacos','0:0:0:0:0:0:0:1','D         ','siwei','');
INSERT INTO his_config_info (id,data_id,group_id,app_name,"content",md5,gmt_create,gmt_modified,src_user,src_ip,op_type,tenant_id,encrypted_data_key) VALUES
                                                                                                                                                                   (26,'ruoyi-gen-dev.yml','DEFAULT_GROUP','','# spring配置
spring:
  redis:
    host: localhost
    port: 6379
    password:
  datasource:
    driver-class-name: org.postgresql.Driver
    url: jdbc:postgresql://192.168.60.221:5432/postgres?currentSchema=ry-cloud&reWriteBatchedInserts=true&useUnicode=true&characterEncoding=utf8&serverTimezone=Asia/Shanghai
    username: postgres
    password: postgis

# mybatis配置
mybatis:
    # 搜索指定包别名
    typeAliasesPackage: com.ruoyi.gen.domain
    # 配置mapper的扫描，找到所有的mapper.xml映射文件
    mapperLocations: classpath:mapper/postgresql/**/*.xml

# springdoc配置
springdoc:
  gatewayUrl: http://localhost:8080/${spring.application.name}
  api-docs:
    # 是否开启接口文档
    enabled: true
  info:
    # 标题
    title: ''代码生成接口文档''
    # 描述
    description: ''代码生成接口描述''
    # 作者信息
    contact:
      name: RuoYi
      url: https://ruoyi.vip

# 代码生成
gen:
  # 作者
  author: ruoyi
  # 默认生成包路径 system 需改成自己的模块名称 如 system monitor tool
  packageName: com.ruoyi.system
  # 自动去除表前缀，默认是false
  autoRemovePre: false
  # 表前缀（生成类名不会包含表前缀，多个用逗号分隔）
  tablePrefix: sys_
  # 是否允许生成文件覆盖到本地（自定义路径），默认不允许
  allowOverwrite: false','adaffd35363045dacb964ff6597b3f89','2025-01-09 13:46:17.437555+08','2025-01-09 13:46:17.392+08','nacos','0:0:0:0:0:0:0:1','D         ','siwei',''),
                                                                                                                                                                   (0,'siwei-monitor-dev.yml','DEFAULT_GROUP','','# spring
spring:
  security:
    user:
      name: siwei
      password: 123456
  boot:
    admin:
      ui:
        title: 若依服务状态监控
','2e1bb8d9ed9c6e404094316b311db2ea','2025-01-09 13:47:04.096673+08','2025-01-09 13:47:04.063+08','nacos','0:0:0:0:0:0:0:1','I         ','siwei',''),
                                                                                                                                                                   (24,'ruoyi-monitor-dev.yml','DEFAULT_GROUP','','# spring
spring:
  security:
    user:
      name: ruoyi
      password: 123456
  boot:
    admin:
      ui:
        title: 若依服务状态监控
','6f122fd2bfb8d45f858e7d6529a9cd44','2025-01-09 13:51:22.545136+08','2025-01-09 13:51:22.482+08','nacos','0:0:0:0:0:0:0:1','D         ','siwei',''),
                                                                                                                                                                   (32,'siwei-gateway-dev.yml','DEFAULT_GROUP','','spring:
  redis:
    host: localhost
    port: 6379
    password:
  cloud:
    gateway:
      discovery:
        locator:
          lowerCaseServiceId: true
          enabled: true
      routes:
        # 认证中心
        - id: ruoyi-auth
          uri: lb://ruoyi-auth
          predicates:
            - Path=/auth/**
          filters:
            # 验证码处理
            - CacheRequestFilter
            - ValidateCodeFilter
            - StripPrefix=1
        # 代码生成
        - id: ruoyi-gen
          uri: lb://ruoyi-gen
          predicates:
            - Path=/code/**
          filters:
            - StripPrefix=1
        # 定时任务
        - id: ruoyi-job
          uri: lb://ruoyi-job
          predicates:
            - Path=/schedule/**
          filters:
            - StripPrefix=1
        # 系统模块
        - id: ruoyi-system
          uri: lb://ruoyi-system
          predicates:
            - Path=/system/**
          filters:
            - StripPrefix=1
        # 文件服务
        - id: ruoyi-file
          uri: lb://ruoyi-file
          predicates:
            - Path=/file/**
          filters:
            - StripPrefix=1

# 安全配置
security:
  # 验证码
  captcha:
    enabled: true
    type: math
  # 防止XSS攻击
  xss:
    enabled: true
    excludeUrls:
      - /system/notice

  # 不校验白名单
  ignore:
    whites:
      - /auth/logout
      - /auth/login
      - /auth/register
      - /*/v2/api-docs
      - /*/v3/api-docs
      - /csrf

# springdoc配置
springdoc:
  webjars:
    # 访问前缀
    prefix:
','4e5585c6a80a82b346056a00d6efe588','2025-01-09 14:36:12.976293+08','2025-01-09 14:36:12.951+08','nacos','0:0:0:0:0:0:0:1','U         ','siwei','');
INSERT INTO roles (username,"role") VALUES
    ('nacos','ROLE_ADMIN');
INSERT INTO tenant_info (kp,tenant_id,tenant_name,tenant_desc,create_source,gmt_create,gmt_modified) VALUES
                                                                                                                  ('1','rsmonitoring','rsmonitoring','rsmonitoring','nacos',1736321533709,1736321533709),
                                                                                                                  ('1','siwei','siwei','siwei','nacos',1736383134026,1736383134026);
INSERT INTO users (username,"password",enabled) VALUES
    ('nacos','$2a$10$EuWPZHzz32dJN7jexM34MOeYirDdFAZm2kuWj7VEOJhhZkDrxfvUu',true);
